'use strict'

const assert = require('assert')
const porExtenso = require('.')

/* global it */

it('not a number', () => {
  assert.throws(() => porExtenso(undefined))
  assert.throws(() => porExtenso(null))
  assert.throws(() => porExtenso(/ /))
})

it('< 0', () => {
  assert.equal(porExtenso(-1), -1)
  assert.equal(porExtenso(-90), -90)
  assert.equal(porExtenso(-99), -99)
  assert.equal(porExtenso(-543), -543)
  assert.equal(porExtenso(-9988), -9988)
})

it('strings', () => {
  assert.equal(porExtenso('-90'), '-90')
  assert.equal(porExtenso('0'), 'zero')
  assert.equal(porExtenso('7'), 'sete')
  assert.equal(porExtenso('123'), 'cento e vinte e três')
  assert.equal(porExtenso('eu comprei 99 balões'), 'eu comprei noventa e nove balões')
  assert.equal(porExtenso.parse('eu comprei noventa e nove balões'), 'eu comprei 99 balões')
  assert.equal(porExtenso.parse('DUZENTOS E TREZE EM CAIXA ALTA'), '213 EM CAIXA ALTA')
  assert.equal(porExtenso.parse('novecentos e novecentos e noventa e nove e nove e novecentos e nove e nove nove nove novecentos e noventa nove novecentos e noventa e nove'), '900 e 999 e 9 e 909 e 9 9 9 990 9 999')
})

it('0-99', () => {
  assert.equal(porExtenso(0), 'zero')
  assert.equal(porExtenso(1), 'um')
  assert.equal(porExtenso(2), 'dois')
  assert.equal(porExtenso(3), 'três')
  assert.equal(porExtenso(4), 'quatro')
  assert.equal(porExtenso(5), 'cinco')
  assert.equal(porExtenso(6), 'seis')
  assert.equal(porExtenso(7), 'sete')
  assert.equal(porExtenso(8), 'oito')

  assert.equal(porExtenso(10), 'dez')
  assert.equal(porExtenso(11), 'onze')
  assert.equal(porExtenso(12), 'doze')
  assert.equal(porExtenso(13), 'treze')
  assert.equal(porExtenso(14), 'quatorze')
  assert.equal(porExtenso(15), 'quinze')
  assert.equal(porExtenso(16), 'dezesseis')
  assert.equal(porExtenso(17), 'dezessete')
  assert.equal(porExtenso(18), 'dezoito')
  assert.equal(porExtenso(19), 'dezenove')

  assert.equal(porExtenso(20), 'vinte')
  assert.equal(porExtenso(21), 'vinte e um')
  assert.equal(porExtenso(22), 'vinte e dois')
  assert.equal(porExtenso(23), 'vinte e três')
  assert.equal(porExtenso(24), 'vinte e quatro')
  assert.equal(porExtenso(25), 'vinte e cinco')
  assert.equal(porExtenso(26), 'vinte e seis')
  assert.equal(porExtenso(27), 'vinte e sete')
  assert.equal(porExtenso(28), 'vinte e oito')
  assert.equal(porExtenso(29), 'vinte e nove')

  assert.equal(porExtenso(30), 'trinta')
  assert.equal(porExtenso(31), 'trinta e um')
  assert.equal(porExtenso(32), 'trinta e dois')
  assert.equal(porExtenso(33), 'trinta e três')
  assert.equal(porExtenso(34), 'trinta e quatro')
  assert.equal(porExtenso(35), 'trinta e cinco')
  assert.equal(porExtenso(36), 'trinta e seis')
  assert.equal(porExtenso(37), 'trinta e sete')
  assert.equal(porExtenso(38), 'trinta e oito')
  assert.equal(porExtenso(39), 'trinta e nove')

  assert.equal(porExtenso(40), 'quarenta')
  assert.equal(porExtenso(41), 'quarenta e um')
  assert.equal(porExtenso(42), 'quarenta e dois')
  assert.equal(porExtenso(43), 'quarenta e três')
  assert.equal(porExtenso(44), 'quarenta e quatro')
  assert.equal(porExtenso(45), 'quarenta e cinco')
  assert.equal(porExtenso(46), 'quarenta e seis')
  assert.equal(porExtenso(47), 'quarenta e sete')
  assert.equal(porExtenso(48), 'quarenta e oito')
  assert.equal(porExtenso(49), 'quarenta e nove')

  assert.equal(porExtenso(50), 'cinquenta')
  assert.equal(porExtenso(51), 'cinquenta e um')
  assert.equal(porExtenso(52), 'cinquenta e dois')
  assert.equal(porExtenso(53), 'cinquenta e três')
  assert.equal(porExtenso(54), 'cinquenta e quatro')
  assert.equal(porExtenso(55), 'cinquenta e cinco')
  assert.equal(porExtenso(56), 'cinquenta e seis')
  assert.equal(porExtenso(57), 'cinquenta e sete')
  assert.equal(porExtenso(58), 'cinquenta e oito')
  assert.equal(porExtenso(59), 'cinquenta e nove')

  assert.equal(porExtenso(60), 'sessenta')
  assert.equal(porExtenso(61), 'sessenta e um')
  assert.equal(porExtenso(62), 'sessenta e dois')
  assert.equal(porExtenso(63), 'sessenta e três')
  assert.equal(porExtenso(64), 'sessenta e quatro')
  assert.equal(porExtenso(65), 'sessenta e cinco')
  assert.equal(porExtenso(66), 'sessenta e seis')
  assert.equal(porExtenso(67), 'sessenta e sete')
  assert.equal(porExtenso(68), 'sessenta e oito')
  assert.equal(porExtenso(69), 'sessenta e nove')

  assert.equal(porExtenso(70), 'setenta')
  assert.equal(porExtenso(71), 'setenta e um')
  assert.equal(porExtenso(72), 'setenta e dois')
  assert.equal(porExtenso(73), 'setenta e três')
  assert.equal(porExtenso(74), 'setenta e quatro')
  assert.equal(porExtenso(75), 'setenta e cinco')
  assert.equal(porExtenso(76), 'setenta e seis')
  assert.equal(porExtenso(77), 'setenta e sete')
  assert.equal(porExtenso(78), 'setenta e oito')
  assert.equal(porExtenso(79), 'setenta e nove')

  assert.equal(porExtenso(80), 'oitenta')
  assert.equal(porExtenso(81), 'oitenta e um')
  assert.equal(porExtenso(82), 'oitenta e dois')
  assert.equal(porExtenso(83), 'oitenta e três')
  assert.equal(porExtenso(84), 'oitenta e quatro')
  assert.equal(porExtenso(85), 'oitenta e cinco')
  assert.equal(porExtenso(86), 'oitenta e seis')
  assert.equal(porExtenso(87), 'oitenta e sete')
  assert.equal(porExtenso(88), 'oitenta e oito')
  assert.equal(porExtenso(89), 'oitenta e nove')

  assert.equal(porExtenso(90), 'noventa')
  assert.equal(porExtenso(91), 'noventa e um')
  assert.equal(porExtenso(92), 'noventa e dois')
  assert.equal(porExtenso(93), 'noventa e três')
  assert.equal(porExtenso(94), 'noventa e quatro')
  assert.equal(porExtenso(95), 'noventa e cinco')
  assert.equal(porExtenso(96), 'noventa e seis')
  assert.equal(porExtenso(97), 'noventa e sete')
  assert.equal(porExtenso(98), 'noventa e oito')
  assert.equal(porExtenso(99), 'noventa e nove')
})

it('zero - noventa e nove', () => {
  assert.equal(porExtenso.parse('zero'), '0')
  assert.equal(porExtenso.parse('um'), '1')
  assert.equal(porExtenso.parse('dois'), '2')
  assert.equal(porExtenso.parse('três'), '3')
  assert.equal(porExtenso.parse('quatro'), '4')
  assert.equal(porExtenso.parse('cinco'), '5')
  assert.equal(porExtenso.parse('seis'), '6')
  assert.equal(porExtenso.parse('sete'), '7')
  assert.equal(porExtenso.parse('oito'), '8')
  assert.equal(porExtenso.parse('nove'), '9')

  assert.equal(porExtenso.parse('dez'), '10')
  assert.equal(porExtenso.parse('onze'), '11')
  assert.equal(porExtenso.parse('doze'), '12')
  assert.equal(porExtenso.parse('treze'), '13')
  assert.equal(porExtenso.parse('quatorze'), '14')
  assert.equal(porExtenso.parse('quinze'), '15')
  assert.equal(porExtenso.parse('dezesseis'), '16')
  assert.equal(porExtenso.parse('dezessete'), '17')
  assert.equal(porExtenso.parse('dezoito'), '18')
  assert.equal(porExtenso.parse('dezenove'), '19')

  assert.equal(porExtenso.parse('vinte'), '20')
  assert.equal(porExtenso.parse('vinte e um'), '21')
  assert.equal(porExtenso.parse('vinte e dois'), '22')
  assert.equal(porExtenso.parse('vinte e três'), '23')
  assert.equal(porExtenso.parse('vinte e quatro'), '24')
  assert.equal(porExtenso.parse('vinte e cinco'), '25')
  assert.equal(porExtenso.parse('vinte e seis'), '26')
  assert.equal(porExtenso.parse('vinte e sete'), '27')
  assert.equal(porExtenso.parse('vinte e oito'), '28')
  assert.equal(porExtenso.parse('vinte e nove'), '29')

  assert.equal(porExtenso.parse('trinta'), '30')
  assert.equal(porExtenso.parse('trinta e um'), '31')
  assert.equal(porExtenso.parse('trinta e dois'), '32')
  assert.equal(porExtenso.parse('trinta e três'), '33')
  assert.equal(porExtenso.parse('trinta e quatro'), '34')
  assert.equal(porExtenso.parse('trinta e cinco'), '35')
  assert.equal(porExtenso.parse('trinta e seis'), '36')
  assert.equal(porExtenso.parse('trinta e sete'), '37')
  assert.equal(porExtenso.parse('trinta e oito'), '38')
  assert.equal(porExtenso.parse('trinta e nove'), '39')

  assert.equal(porExtenso.parse('quarenta'), '40')
  assert.equal(porExtenso.parse('quarenta e um'), '41')
  assert.equal(porExtenso.parse('quarenta e dois'), '42')
  assert.equal(porExtenso.parse('quarenta e três'), '43')
  assert.equal(porExtenso.parse('quarenta e quatro'), '44')
  assert.equal(porExtenso.parse('quarenta e cinco'), '45')
  assert.equal(porExtenso.parse('quarenta e seis'), '46')
  assert.equal(porExtenso.parse('quarenta e sete'), '47')
  assert.equal(porExtenso.parse('quarenta e oito'), '48')
  assert.equal(porExtenso.parse('quarenta e nove'), '49')

  assert.equal(porExtenso.parse('cinquenta'), '50')
  assert.equal(porExtenso.parse('cinquenta e um'), '51')
  assert.equal(porExtenso.parse('cinquenta e dois'), '52')
  assert.equal(porExtenso.parse('cinquenta e três'), '53')
  assert.equal(porExtenso.parse('cinquenta e quatro'), '54')
  assert.equal(porExtenso.parse('cinquenta e cinco'), '55')
  assert.equal(porExtenso.parse('cinquenta e seis'), '56')
  assert.equal(porExtenso.parse('cinquenta e sete'), '57')
  assert.equal(porExtenso.parse('cinquenta e oito'), '58')
  assert.equal(porExtenso.parse('cinquenta e nove'), '59')

  assert.equal(porExtenso.parse('sessenta'), '60')
  assert.equal(porExtenso.parse('sessenta e um'), '61')
  assert.equal(porExtenso.parse('sessenta e dois'), '62')
  assert.equal(porExtenso.parse('sessenta e três'), '63')
  assert.equal(porExtenso.parse('sessenta e quatro'), '64')
  assert.equal(porExtenso.parse('sessenta e cinco'), '65')
  assert.equal(porExtenso.parse('sessenta e seis'), '66')
  assert.equal(porExtenso.parse('sessenta e sete'), '67')
  assert.equal(porExtenso.parse('sessenta e oito'), '68')
  assert.equal(porExtenso.parse('sessenta e nove'), '69')

  assert.equal(porExtenso.parse('setenta'), '70')
  assert.equal(porExtenso.parse('setenta e um'), '71')
  assert.equal(porExtenso.parse('setenta e dois'), '72')
  assert.equal(porExtenso.parse('setenta e três'), '73')
  assert.equal(porExtenso.parse('setenta e quatro'), '74')
  assert.equal(porExtenso.parse('setenta e cinco'), '75')
  assert.equal(porExtenso.parse('setenta e seis'), '76')
  assert.equal(porExtenso.parse('setenta e sete'), '77')
  assert.equal(porExtenso.parse('setenta e oito'), '78')
  assert.equal(porExtenso.parse('setenta e nove'), '79')

  assert.equal(porExtenso.parse('oitenta'), '80')
  assert.equal(porExtenso.parse('oitenta e um'), '81')
  assert.equal(porExtenso.parse('oitenta e dois'), '82')
  assert.equal(porExtenso.parse('oitenta e três'), '83')
  assert.equal(porExtenso.parse('oitenta e quatro'), '84')
  assert.equal(porExtenso.parse('oitenta e cinco'), '85')
  assert.equal(porExtenso.parse('oitenta e seis'), '86')
  assert.equal(porExtenso.parse('oitenta e sete'), '87')
  assert.equal(porExtenso.parse('oitenta e oito'), '88')
  assert.equal(porExtenso.parse('oitenta e nove'), '89')

  assert.equal(porExtenso.parse('noventa'), '90')
  assert.equal(porExtenso.parse('noventa e um'), '91')
  assert.equal(porExtenso.parse('noventa e dois'), '92')
  assert.equal(porExtenso.parse('noventa e três'), '93')
  assert.equal(porExtenso.parse('noventa e quatro'), '94')
  assert.equal(porExtenso.parse('noventa e cinco'), '95')
  assert.equal(porExtenso.parse('noventa e seis'), '96')
  assert.equal(porExtenso.parse('noventa e sete'), '97')
  assert.equal(porExtenso.parse('noventa e oito'), '98')
  assert.equal(porExtenso.parse('noventa e nove'), '99')
})

it('100+', () => {
  assert.equal(porExtenso(100), 'cem')
  assert.equal(porExtenso(101), 'cento e um')
  assert.equal(porExtenso(102), 'cento e dois')
  assert.equal(porExtenso(103), 'cento e três')
  assert.equal(porExtenso(104), 'cento e quatro')
  assert.equal(porExtenso(105), 'cento e cinco')
  assert.equal(porExtenso(106), 'cento e seis')
  assert.equal(porExtenso(107), 'cento e sete')
  assert.equal(porExtenso(108), 'cento e oito')
  assert.equal(porExtenso(109), 'cento e nove')

  assert.equal(porExtenso(110), 'cento e dez')
  assert.equal(porExtenso(111), 'cento e onze')
  assert.equal(porExtenso(112), 'cento e doze')
  assert.equal(porExtenso(113), 'cento e treze')
  assert.equal(porExtenso(114), 'cento e quatorze')
  assert.equal(porExtenso(115), 'cento e quinze')
  assert.equal(porExtenso(116), 'cento e dezesseis')
  assert.equal(porExtenso(117), 'cento e dezessete')
  assert.equal(porExtenso(118), 'cento e dezoito')
  assert.equal(porExtenso(119), 'cento e dezenove')

  assert.equal(porExtenso(120), 'cento e vinte')
  assert.equal(porExtenso(121), 'cento e vinte e um')
  assert.equal(porExtenso(122), 'cento e vinte e dois')
  assert.equal(porExtenso(123), 'cento e vinte e três')
  assert.equal(porExtenso(124), 'cento e vinte e quatro')
  assert.equal(porExtenso(125), 'cento e vinte e cinco')
  assert.equal(porExtenso(126), 'cento e vinte e seis')
  assert.equal(porExtenso(127), 'cento e vinte e sete')
  assert.equal(porExtenso(128), 'cento e vinte e oito')
  assert.equal(porExtenso(129), 'cento e vinte e nove')

  assert.equal(porExtenso(130), 'cento e trinta')
  assert.equal(porExtenso(131), 'cento e trinta e um')
  assert.equal(porExtenso(132), 'cento e trinta e dois')
  assert.equal(porExtenso(133), 'cento e trinta e três')
  assert.equal(porExtenso(134), 'cento e trinta e quatro')
  assert.equal(porExtenso(135), 'cento e trinta e cinco')
  assert.equal(porExtenso(136), 'cento e trinta e seis')
  assert.equal(porExtenso(137), 'cento e trinta e sete')
  assert.equal(porExtenso(138), 'cento e trinta e oito')
  assert.equal(porExtenso(139), 'cento e trinta e nove')

  assert.equal(porExtenso(140), 'cento e quarenta')
  assert.equal(porExtenso(141), 'cento e quarenta e um')
  assert.equal(porExtenso(142), 'cento e quarenta e dois')
  assert.equal(porExtenso(143), 'cento e quarenta e três')
  assert.equal(porExtenso(144), 'cento e quarenta e quatro')
  assert.equal(porExtenso(145), 'cento e quarenta e cinco')
  assert.equal(porExtenso(146), 'cento e quarenta e seis')
  assert.equal(porExtenso(147), 'cento e quarenta e sete')
  assert.equal(porExtenso(148), 'cento e quarenta e oito')
  assert.equal(porExtenso(149), 'cento e quarenta e nove')

  assert.equal(porExtenso(150), 'cento e cinquenta')
  assert.equal(porExtenso(151), 'cento e cinquenta e um')
  assert.equal(porExtenso(152), 'cento e cinquenta e dois')
  assert.equal(porExtenso(153), 'cento e cinquenta e três')
  assert.equal(porExtenso(154), 'cento e cinquenta e quatro')
  assert.equal(porExtenso(155), 'cento e cinquenta e cinco')
  assert.equal(porExtenso(156), 'cento e cinquenta e seis')
  assert.equal(porExtenso(157), 'cento e cinquenta e sete')
  assert.equal(porExtenso(158), 'cento e cinquenta e oito')
  assert.equal(porExtenso(159), 'cento e cinquenta e nove')

  assert.equal(porExtenso(160), 'cento e sessenta')
  assert.equal(porExtenso(161), 'cento e sessenta e um')
  assert.equal(porExtenso(162), 'cento e sessenta e dois')
  assert.equal(porExtenso(163), 'cento e sessenta e três')
  assert.equal(porExtenso(164), 'cento e sessenta e quatro')
  assert.equal(porExtenso(165), 'cento e sessenta e cinco')
  assert.equal(porExtenso(166), 'cento e sessenta e seis')
  assert.equal(porExtenso(167), 'cento e sessenta e sete')
  assert.equal(porExtenso(168), 'cento e sessenta e oito')
  assert.equal(porExtenso(169), 'cento e sessenta e nove')

  assert.equal(porExtenso(170), 'cento e setenta')
  assert.equal(porExtenso(171), 'cento e setenta e um')
  assert.equal(porExtenso(172), 'cento e setenta e dois')
  assert.equal(porExtenso(173), 'cento e setenta e três')
  assert.equal(porExtenso(174), 'cento e setenta e quatro')
  assert.equal(porExtenso(175), 'cento e setenta e cinco')
  assert.equal(porExtenso(176), 'cento e setenta e seis')
  assert.equal(porExtenso(177), 'cento e setenta e sete')
  assert.equal(porExtenso(178), 'cento e setenta e oito')
  assert.equal(porExtenso(179), 'cento e setenta e nove')

  assert.equal(porExtenso(180), 'cento e oitenta')
  assert.equal(porExtenso(181), 'cento e oitenta e um')
  assert.equal(porExtenso(182), 'cento e oitenta e dois')
  assert.equal(porExtenso(183), 'cento e oitenta e três')
  assert.equal(porExtenso(184), 'cento e oitenta e quatro')
  assert.equal(porExtenso(185), 'cento e oitenta e cinco')
  assert.equal(porExtenso(186), 'cento e oitenta e seis')
  assert.equal(porExtenso(187), 'cento e oitenta e sete')
  assert.equal(porExtenso(188), 'cento e oitenta e oito')
  assert.equal(porExtenso(189), 'cento e oitenta e nove')

  assert.equal(porExtenso(190), 'cento e noventa')
  assert.equal(porExtenso(191), 'cento e noventa e um')
  assert.equal(porExtenso(192), 'cento e noventa e dois')
  assert.equal(porExtenso(193), 'cento e noventa e três')
  assert.equal(porExtenso(194), 'cento e noventa e quatro')
  assert.equal(porExtenso(195), 'cento e noventa e cinco')
  assert.equal(porExtenso(196), 'cento e noventa e seis')
  assert.equal(porExtenso(197), 'cento e noventa e sete')
  assert.equal(porExtenso(198), 'cento e noventa e oito')
  assert.equal(porExtenso(199), 'cento e noventa e nove')
})

it('cem+', () => {
  assert.equal(porExtenso.parse('cem'), '100')
  assert.equal(porExtenso.parse('cento e um'), '101')
  assert.equal(porExtenso.parse('cento e dois'), '102')
  assert.equal(porExtenso.parse('cento e três'), '103')
  assert.equal(porExtenso.parse('cento e quatro'), '104')
  assert.equal(porExtenso.parse('cento e cinco'), '105')
  assert.equal(porExtenso.parse('cento e seis'), '106')
  assert.equal(porExtenso.parse('cento e sete'), '107')
  assert.equal(porExtenso.parse('cento e oito'), '108')
  assert.equal(porExtenso.parse('cento e nove'), '109')

  assert.equal(porExtenso.parse('cento e dez'), '110')
  assert.equal(porExtenso.parse('cento e onze'), '111')
  assert.equal(porExtenso.parse('cento e doze'), '112')
  assert.equal(porExtenso.parse('cento e treze'), '113')
  assert.equal(porExtenso.parse('cento e quatorze'), '114')
  assert.equal(porExtenso.parse('cento e quinze'), '115')
  assert.equal(porExtenso.parse('cento e dezesseis'), '116')
  assert.equal(porExtenso.parse('cento e dezessete'), '117')
  assert.equal(porExtenso.parse('cento e dezoito'), '118')
  assert.equal(porExtenso.parse('cento e dezenove'), '119')

  assert.equal(porExtenso.parse('cento e vinte'), '120')
  assert.equal(porExtenso.parse('cento e vinte e um'), '121')
  assert.equal(porExtenso.parse('cento e vinte e dois'), '122')
  assert.equal(porExtenso.parse('cento e vinte e três'), '123')
  assert.equal(porExtenso.parse('cento e vinte e quatro'), '124')
  assert.equal(porExtenso.parse('cento e vinte e cinco'), '125')
  assert.equal(porExtenso.parse('cento e vinte e seis'), '126')
  assert.equal(porExtenso.parse('cento e vinte e sete'), '127')
  assert.equal(porExtenso.parse('cento e vinte e oito'), '128')
  assert.equal(porExtenso.parse('cento e vinte e nove'), '129')

  assert.equal(porExtenso.parse('cento e trinta'), '130')
  assert.equal(porExtenso.parse('cento e trinta e um'), '131')
  assert.equal(porExtenso.parse('cento e trinta e dois'), '132')
  assert.equal(porExtenso.parse('cento e trinta e três'), '133')
  assert.equal(porExtenso.parse('cento e trinta e quatro'), '134')
  assert.equal(porExtenso.parse('cento e trinta e cinco'), '135')
  assert.equal(porExtenso.parse('cento e trinta e seis'), '136')
  assert.equal(porExtenso.parse('cento e trinta e sete'), '137')
  assert.equal(porExtenso.parse('cento e trinta e oito'), '138')
  assert.equal(porExtenso.parse('cento e trinta e nove'), '139')

  assert.equal(porExtenso.parse('cento e quarenta'), '140')
  assert.equal(porExtenso.parse('cento e quarenta e um'), '141')
  assert.equal(porExtenso.parse('cento e quarenta e dois'), '142')
  assert.equal(porExtenso.parse('cento e quarenta e três'), '143')
  assert.equal(porExtenso.parse('cento e quarenta e quatro'), '144')
  assert.equal(porExtenso.parse('cento e quarenta e cinco'), '145')
  assert.equal(porExtenso.parse('cento e quarenta e seis'), '146')
  assert.equal(porExtenso.parse('cento e quarenta e sete'), '147')
  assert.equal(porExtenso.parse('cento e quarenta e oito'), '148')
  assert.equal(porExtenso.parse('cento e quarenta e nove'), '149')

  assert.equal(porExtenso.parse('cento e cinquenta'), '150')
  assert.equal(porExtenso.parse('cento e cinquenta e um'), '151')
  assert.equal(porExtenso.parse('cento e cinquenta e dois'), '152')
  assert.equal(porExtenso.parse('cento e cinquenta e três'), '153')
  assert.equal(porExtenso.parse('cento e cinquenta e quatro'), '154')
  assert.equal(porExtenso.parse('cento e cinquenta e cinco'), '155')
  assert.equal(porExtenso.parse('cento e cinquenta e seis'), '156')
  assert.equal(porExtenso.parse('cento e cinquenta e sete'), '157')
  assert.equal(porExtenso.parse('cento e cinquenta e oito'), '158')
  assert.equal(porExtenso.parse('cento e cinquenta e nove'), '159')

  assert.equal(porExtenso.parse('cento e sessenta'), '160')
  assert.equal(porExtenso.parse('cento e sessenta e um'), '161')
  assert.equal(porExtenso.parse('cento e sessenta e dois'), '162')
  assert.equal(porExtenso.parse('cento e sessenta e três'), '163')
  assert.equal(porExtenso.parse('cento e sessenta e quatro'), '164')
  assert.equal(porExtenso.parse('cento e sessenta e cinco'), '165')
  assert.equal(porExtenso.parse('cento e sessenta e seis'), '166')
  assert.equal(porExtenso.parse('cento e sessenta e sete'), '167')
  assert.equal(porExtenso.parse('cento e sessenta e oito'), '168')
  assert.equal(porExtenso.parse('cento e sessenta e nove'), '169')

  assert.equal(porExtenso.parse('cento e setenta'), '170')
  assert.equal(porExtenso.parse('cento e setenta e um'), '171')
  assert.equal(porExtenso.parse('cento e setenta e dois'), '172')
  assert.equal(porExtenso.parse('cento e setenta e três'), '173')
  assert.equal(porExtenso.parse('cento e setenta e quatro'), '174')
  assert.equal(porExtenso.parse('cento e setenta e cinco'), '175')
  assert.equal(porExtenso.parse('cento e setenta e seis'), '176')
  assert.equal(porExtenso.parse('cento e setenta e sete'), '177')
  assert.equal(porExtenso.parse('cento e setenta e oito'), '178')
  assert.equal(porExtenso.parse('cento e setenta e nove'), '179')

  assert.equal(porExtenso.parse('cento e oitenta'), '180')
  assert.equal(porExtenso.parse('cento e oitenta e um'), '181')
  assert.equal(porExtenso.parse('cento e oitenta e dois'), '182')
  assert.equal(porExtenso.parse('cento e oitenta e três'), '183')
  assert.equal(porExtenso.parse('cento e oitenta e quatro'), '184')
  assert.equal(porExtenso.parse('cento e oitenta e cinco'), '185')
  assert.equal(porExtenso.parse('cento e oitenta e seis'), '186')
  assert.equal(porExtenso.parse('cento e oitenta e sete'), '187')
  assert.equal(porExtenso.parse('cento e oitenta e oito'), '188')
  assert.equal(porExtenso.parse('cento e oitenta e nove'), '189')

  assert.equal(porExtenso.parse('cento e noventa'), '190')
  assert.equal(porExtenso.parse('cento e noventa e um'), '191')
  assert.equal(porExtenso.parse('cento e noventa e dois'), '192')
  assert.equal(porExtenso.parse('cento e noventa e três'), '193')
  assert.equal(porExtenso.parse('cento e noventa e quatro'), '194')
  assert.equal(porExtenso.parse('cento e noventa e cinco'), '195')
  assert.equal(porExtenso.parse('cento e noventa e seis'), '196')
  assert.equal(porExtenso.parse('cento e noventa e sete'), '197')
  assert.equal(porExtenso.parse('cento e noventa e oito'), '198')
  assert.equal(porExtenso.parse('cento e noventa e nove'), '199')
})

it('200+', () => {
  assert.equal(porExtenso(200), 'duzentos')
  assert.equal(porExtenso(201), 'duzentos e um')
  assert.equal(porExtenso(202), 'duzentos e dois')
  assert.equal(porExtenso(203), 'duzentos e três')
  assert.equal(porExtenso(204), 'duzentos e quatro')
  assert.equal(porExtenso(205), 'duzentos e cinco')
  assert.equal(porExtenso(206), 'duzentos e seis')
  assert.equal(porExtenso(207), 'duzentos e sete')
  assert.equal(porExtenso(208), 'duzentos e oito')
  assert.equal(porExtenso(209), 'duzentos e nove')

  assert.equal(porExtenso(210), 'duzentos e dez')
  assert.equal(porExtenso(211), 'duzentos e onze')
  assert.equal(porExtenso(212), 'duzentos e doze')
  assert.equal(porExtenso(213), 'duzentos e treze')
  assert.equal(porExtenso(214), 'duzentos e quatorze')
  assert.equal(porExtenso(215), 'duzentos e quinze')
  assert.equal(porExtenso(216), 'duzentos e dezesseis')
  assert.equal(porExtenso(217), 'duzentos e dezessete')
  assert.equal(porExtenso(218), 'duzentos e dezoito')
  assert.equal(porExtenso(219), 'duzentos e dezenove')

  assert.equal(porExtenso(220), 'duzentos e vinte')
  assert.equal(porExtenso(221), 'duzentos e vinte e um')
  assert.equal(porExtenso(222), 'duzentos e vinte e dois')
  assert.equal(porExtenso(223), 'duzentos e vinte e três')
  assert.equal(porExtenso(224), 'duzentos e vinte e quatro')
  assert.equal(porExtenso(225), 'duzentos e vinte e cinco')
  assert.equal(porExtenso(226), 'duzentos e vinte e seis')
  assert.equal(porExtenso(227), 'duzentos e vinte e sete')
  assert.equal(porExtenso(228), 'duzentos e vinte e oito')
  assert.equal(porExtenso(229), 'duzentos e vinte e nove')

  assert.equal(porExtenso(230), 'duzentos e trinta')
  assert.equal(porExtenso(231), 'duzentos e trinta e um')
  assert.equal(porExtenso(232), 'duzentos e trinta e dois')
  assert.equal(porExtenso(233), 'duzentos e trinta e três')
  assert.equal(porExtenso(234), 'duzentos e trinta e quatro')
  assert.equal(porExtenso(235), 'duzentos e trinta e cinco')
  assert.equal(porExtenso(236), 'duzentos e trinta e seis')
  assert.equal(porExtenso(237), 'duzentos e trinta e sete')
  assert.equal(porExtenso(238), 'duzentos e trinta e oito')
  assert.equal(porExtenso(239), 'duzentos e trinta e nove')

  assert.equal(porExtenso(240), 'duzentos e quarenta')
  assert.equal(porExtenso(241), 'duzentos e quarenta e um')
  assert.equal(porExtenso(242), 'duzentos e quarenta e dois')
  assert.equal(porExtenso(243), 'duzentos e quarenta e três')
  assert.equal(porExtenso(244), 'duzentos e quarenta e quatro')
  assert.equal(porExtenso(245), 'duzentos e quarenta e cinco')
  assert.equal(porExtenso(246), 'duzentos e quarenta e seis')
  assert.equal(porExtenso(247), 'duzentos e quarenta e sete')
  assert.equal(porExtenso(248), 'duzentos e quarenta e oito')
  assert.equal(porExtenso(249), 'duzentos e quarenta e nove')

  assert.equal(porExtenso(250), 'duzentos e cinquenta')
  assert.equal(porExtenso(251), 'duzentos e cinquenta e um')
  assert.equal(porExtenso(252), 'duzentos e cinquenta e dois')
  assert.equal(porExtenso(253), 'duzentos e cinquenta e três')
  assert.equal(porExtenso(254), 'duzentos e cinquenta e quatro')
  assert.equal(porExtenso(255), 'duzentos e cinquenta e cinco')
  assert.equal(porExtenso(256), 'duzentos e cinquenta e seis')
  assert.equal(porExtenso(257), 'duzentos e cinquenta e sete')
  assert.equal(porExtenso(258), 'duzentos e cinquenta e oito')
  assert.equal(porExtenso(259), 'duzentos e cinquenta e nove')

  assert.equal(porExtenso(260), 'duzentos e sessenta')
  assert.equal(porExtenso(261), 'duzentos e sessenta e um')
  assert.equal(porExtenso(262), 'duzentos e sessenta e dois')
  assert.equal(porExtenso(263), 'duzentos e sessenta e três')
  assert.equal(porExtenso(264), 'duzentos e sessenta e quatro')
  assert.equal(porExtenso(265), 'duzentos e sessenta e cinco')
  assert.equal(porExtenso(266), 'duzentos e sessenta e seis')
  assert.equal(porExtenso(267), 'duzentos e sessenta e sete')
  assert.equal(porExtenso(268), 'duzentos e sessenta e oito')
  assert.equal(porExtenso(269), 'duzentos e sessenta e nove')

  assert.equal(porExtenso(270), 'duzentos e setenta')
  assert.equal(porExtenso(271), 'duzentos e setenta e um')
  assert.equal(porExtenso(272), 'duzentos e setenta e dois')
  assert.equal(porExtenso(273), 'duzentos e setenta e três')
  assert.equal(porExtenso(274), 'duzentos e setenta e quatro')
  assert.equal(porExtenso(275), 'duzentos e setenta e cinco')
  assert.equal(porExtenso(276), 'duzentos e setenta e seis')
  assert.equal(porExtenso(277), 'duzentos e setenta e sete')
  assert.equal(porExtenso(278), 'duzentos e setenta e oito')
  assert.equal(porExtenso(279), 'duzentos e setenta e nove')

  assert.equal(porExtenso(280), 'duzentos e oitenta')
  assert.equal(porExtenso(281), 'duzentos e oitenta e um')
  assert.equal(porExtenso(282), 'duzentos e oitenta e dois')
  assert.equal(porExtenso(283), 'duzentos e oitenta e três')
  assert.equal(porExtenso(284), 'duzentos e oitenta e quatro')
  assert.equal(porExtenso(285), 'duzentos e oitenta e cinco')
  assert.equal(porExtenso(286), 'duzentos e oitenta e seis')
  assert.equal(porExtenso(287), 'duzentos e oitenta e sete')
  assert.equal(porExtenso(288), 'duzentos e oitenta e oito')
  assert.equal(porExtenso(289), 'duzentos e oitenta e nove')

  assert.equal(porExtenso(290), 'duzentos e noventa')
  assert.equal(porExtenso(291), 'duzentos e noventa e um')
  assert.equal(porExtenso(292), 'duzentos e noventa e dois')
  assert.equal(porExtenso(293), 'duzentos e noventa e três')
  assert.equal(porExtenso(294), 'duzentos e noventa e quatro')
  assert.equal(porExtenso(295), 'duzentos e noventa e cinco')
  assert.equal(porExtenso(296), 'duzentos e noventa e seis')
  assert.equal(porExtenso(297), 'duzentos e noventa e sete')
  assert.equal(porExtenso(298), 'duzentos e noventa e oito')
  assert.equal(porExtenso(299), 'duzentos e noventa e nove')
})

it('duzentos+', () => {
  assert.equal(porExtenso.parse('duzentos'), '200')
  assert.equal(porExtenso.parse('duzentos e um'), '201')
  assert.equal(porExtenso.parse('duzentos e dois'), '202')
  assert.equal(porExtenso.parse('duzentos e três'), '203')
  assert.equal(porExtenso.parse('duzentos e quatro'), '204')
  assert.equal(porExtenso.parse('duzentos e cinco'), '205')
  assert.equal(porExtenso.parse('duzentos e seis'), '206')
  assert.equal(porExtenso.parse('duzentos e sete'), '207')
  assert.equal(porExtenso.parse('duzentos e oito'), '208')
  assert.equal(porExtenso.parse('duzentos e nove'), '209')

  assert.equal(porExtenso.parse('duzentos e dez'), '210')
  assert.equal(porExtenso.parse('duzentos e onze'), '211')
  assert.equal(porExtenso.parse('duzentos e doze'), '212')
  assert.equal(porExtenso.parse('duzentos e treze'), '213')
  assert.equal(porExtenso.parse('duzentos e quatorze'), '214')
  assert.equal(porExtenso.parse('duzentos e quinze'), '215')
  assert.equal(porExtenso.parse('duzentos e dezesseis'), '216')
  assert.equal(porExtenso.parse('duzentos e dezessete'), '217')
  assert.equal(porExtenso.parse('duzentos e dezoito'), '218')
  assert.equal(porExtenso.parse('duzentos e dezenove'), '219')

  assert.equal(porExtenso.parse('duzentos e vinte'), '220')
  assert.equal(porExtenso.parse('duzentos e vinte e um'), '221')
  assert.equal(porExtenso.parse('duzentos e vinte e dois'), '222')
  assert.equal(porExtenso.parse('duzentos e vinte e três'), '223')
  assert.equal(porExtenso.parse('duzentos e vinte e quatro'), '224')
  assert.equal(porExtenso.parse('duzentos e vinte e cinco'), '225')
  assert.equal(porExtenso.parse('duzentos e vinte e seis'), '226')
  assert.equal(porExtenso.parse('duzentos e vinte e sete'), '227')
  assert.equal(porExtenso.parse('duzentos e vinte e oito'), '228')
  assert.equal(porExtenso.parse('duzentos e vinte e nove'), '229')

  assert.equal(porExtenso.parse('duzentos e trinta'), '230')
  assert.equal(porExtenso.parse('duzentos e trinta e um'), '231')
  assert.equal(porExtenso.parse('duzentos e trinta e dois'), '232')
  assert.equal(porExtenso.parse('duzentos e trinta e três'), '233')
  assert.equal(porExtenso.parse('duzentos e trinta e quatro'), '234')
  assert.equal(porExtenso.parse('duzentos e trinta e cinco'), '235')
  assert.equal(porExtenso.parse('duzentos e trinta e seis'), '236')
  assert.equal(porExtenso.parse('duzentos e trinta e sete'), '237')
  assert.equal(porExtenso.parse('duzentos e trinta e oito'), '238')
  assert.equal(porExtenso.parse('duzentos e trinta e nove'), '239')

  assert.equal(porExtenso.parse('duzentos e quarenta'), '240')
  assert.equal(porExtenso.parse('duzentos e quarenta e um'), '241')
  assert.equal(porExtenso.parse('duzentos e quarenta e dois'), '242')
  assert.equal(porExtenso.parse('duzentos e quarenta e três'), '243')
  assert.equal(porExtenso.parse('duzentos e quarenta e quatro'), '244')
  assert.equal(porExtenso.parse('duzentos e quarenta e cinco'), '245')
  assert.equal(porExtenso.parse('duzentos e quarenta e seis'), '246')
  assert.equal(porExtenso.parse('duzentos e quarenta e sete'), '247')
  assert.equal(porExtenso.parse('duzentos e quarenta e oito'), '248')
  assert.equal(porExtenso.parse('duzentos e quarenta e nove'), '249')

  assert.equal(porExtenso.parse('duzentos e cinquenta'), '250')
  assert.equal(porExtenso.parse('duzentos e cinquenta e um'), '251')
  assert.equal(porExtenso.parse('duzentos e cinquenta e dois'), '252')
  assert.equal(porExtenso.parse('duzentos e cinquenta e três'), '253')
  assert.equal(porExtenso.parse('duzentos e cinquenta e quatro'), '254')
  assert.equal(porExtenso.parse('duzentos e cinquenta e cinco'), '255')
  assert.equal(porExtenso.parse('duzentos e cinquenta e seis'), '256')
  assert.equal(porExtenso.parse('duzentos e cinquenta e sete'), '257')
  assert.equal(porExtenso.parse('duzentos e cinquenta e oito'), '258')
  assert.equal(porExtenso.parse('duzentos e cinquenta e nove'), '259')

  assert.equal(porExtenso.parse('duzentos e sessenta'), '260')
  assert.equal(porExtenso.parse('duzentos e sessenta e um'), '261')
  assert.equal(porExtenso.parse('duzentos e sessenta e dois'), '262')
  assert.equal(porExtenso.parse('duzentos e sessenta e três'), '263')
  assert.equal(porExtenso.parse('duzentos e sessenta e quatro'), '264')
  assert.equal(porExtenso.parse('duzentos e sessenta e cinco'), '265')
  assert.equal(porExtenso.parse('duzentos e sessenta e seis'), '266')
  assert.equal(porExtenso.parse('duzentos e sessenta e sete'), '267')
  assert.equal(porExtenso.parse('duzentos e sessenta e oito'), '268')
  assert.equal(porExtenso.parse('duzentos e sessenta e nove'), '269')

  assert.equal(porExtenso.parse('duzentos e setenta'), '270')
  assert.equal(porExtenso.parse('duzentos e setenta e um'), '271')
  assert.equal(porExtenso.parse('duzentos e setenta e dois'), '272')
  assert.equal(porExtenso.parse('duzentos e setenta e três'), '273')
  assert.equal(porExtenso.parse('duzentos e setenta e quatro'), '274')
  assert.equal(porExtenso.parse('duzentos e setenta e cinco'), '275')
  assert.equal(porExtenso.parse('duzentos e setenta e seis'), '276')
  assert.equal(porExtenso.parse('duzentos e setenta e sete'), '277')
  assert.equal(porExtenso.parse('duzentos e setenta e oito'), '278')
  assert.equal(porExtenso.parse('duzentos e setenta e nove'), '279')

  assert.equal(porExtenso.parse('duzentos e oitenta'), '280')
  assert.equal(porExtenso.parse('duzentos e oitenta e um'), '281')
  assert.equal(porExtenso.parse('duzentos e oitenta e dois'), '282')
  assert.equal(porExtenso.parse('duzentos e oitenta e três'), '283')
  assert.equal(porExtenso.parse('duzentos e oitenta e quatro'), '284')
  assert.equal(porExtenso.parse('duzentos e oitenta e cinco'), '285')
  assert.equal(porExtenso.parse('duzentos e oitenta e seis'), '286')
  assert.equal(porExtenso.parse('duzentos e oitenta e sete'), '287')
  assert.equal(porExtenso.parse('duzentos e oitenta e oito'), '288')
  assert.equal(porExtenso.parse('duzentos e oitenta e nove'), '289')

  assert.equal(porExtenso.parse('duzentos e noventa'), '290')
  assert.equal(porExtenso.parse('duzentos e noventa e um'), '291')
  assert.equal(porExtenso.parse('duzentos e noventa e dois'), '292')
  assert.equal(porExtenso.parse('duzentos e noventa e três'), '293')
  assert.equal(porExtenso.parse('duzentos e noventa e quatro'), '294')
  assert.equal(porExtenso.parse('duzentos e noventa e cinco'), '295')
  assert.equal(porExtenso.parse('duzentos e noventa e seis'), '296')
  assert.equal(porExtenso.parse('duzentos e noventa e sete'), '297')
  assert.equal(porExtenso.parse('duzentos e noventa e oito'), '298')
  assert.equal(porExtenso.parse('duzentos e noventa e nove'), '299')
})

it('300+', () => {
  assert.equal(porExtenso(300), 'trezentos')
  assert.equal(porExtenso(301), 'trezentos e um')
  assert.equal(porExtenso(302), 'trezentos e dois')
  assert.equal(porExtenso(303), 'trezentos e três')
  assert.equal(porExtenso(304), 'trezentos e quatro')
  assert.equal(porExtenso(305), 'trezentos e cinco')
  assert.equal(porExtenso(306), 'trezentos e seis')
  assert.equal(porExtenso(307), 'trezentos e sete')
  assert.equal(porExtenso(308), 'trezentos e oito')
  assert.equal(porExtenso(309), 'trezentos e nove')

  assert.equal(porExtenso(310), 'trezentos e dez')
  assert.equal(porExtenso(311), 'trezentos e onze')
  assert.equal(porExtenso(312), 'trezentos e doze')
  assert.equal(porExtenso(313), 'trezentos e treze')
  assert.equal(porExtenso(314), 'trezentos e quatorze')
  assert.equal(porExtenso(315), 'trezentos e quinze')
  assert.equal(porExtenso(316), 'trezentos e dezesseis')
  assert.equal(porExtenso(317), 'trezentos e dezessete')
  assert.equal(porExtenso(318), 'trezentos e dezoito')
  assert.equal(porExtenso(319), 'trezentos e dezenove')

  assert.equal(porExtenso(320), 'trezentos e vinte')
  assert.equal(porExtenso(321), 'trezentos e vinte e um')
  assert.equal(porExtenso(322), 'trezentos e vinte e dois')
  assert.equal(porExtenso(323), 'trezentos e vinte e três')
  assert.equal(porExtenso(324), 'trezentos e vinte e quatro')
  assert.equal(porExtenso(325), 'trezentos e vinte e cinco')
  assert.equal(porExtenso(326), 'trezentos e vinte e seis')
  assert.equal(porExtenso(327), 'trezentos e vinte e sete')
  assert.equal(porExtenso(328), 'trezentos e vinte e oito')
  assert.equal(porExtenso(329), 'trezentos e vinte e nove')

  assert.equal(porExtenso(330), 'trezentos e trinta')
  assert.equal(porExtenso(331), 'trezentos e trinta e um')
  assert.equal(porExtenso(332), 'trezentos e trinta e dois')
  assert.equal(porExtenso(333), 'trezentos e trinta e três')
  assert.equal(porExtenso(334), 'trezentos e trinta e quatro')
  assert.equal(porExtenso(335), 'trezentos e trinta e cinco')
  assert.equal(porExtenso(336), 'trezentos e trinta e seis')
  assert.equal(porExtenso(337), 'trezentos e trinta e sete')
  assert.equal(porExtenso(338), 'trezentos e trinta e oito')
  assert.equal(porExtenso(339), 'trezentos e trinta e nove')

  assert.equal(porExtenso(340), 'trezentos e quarenta')
  assert.equal(porExtenso(341), 'trezentos e quarenta e um')
  assert.equal(porExtenso(342), 'trezentos e quarenta e dois')
  assert.equal(porExtenso(343), 'trezentos e quarenta e três')
  assert.equal(porExtenso(344), 'trezentos e quarenta e quatro')
  assert.equal(porExtenso(345), 'trezentos e quarenta e cinco')
  assert.equal(porExtenso(346), 'trezentos e quarenta e seis')
  assert.equal(porExtenso(347), 'trezentos e quarenta e sete')
  assert.equal(porExtenso(348), 'trezentos e quarenta e oito')
  assert.equal(porExtenso(349), 'trezentos e quarenta e nove')

  assert.equal(porExtenso(350), 'trezentos e cinquenta')
  assert.equal(porExtenso(351), 'trezentos e cinquenta e um')
  assert.equal(porExtenso(352), 'trezentos e cinquenta e dois')
  assert.equal(porExtenso(353), 'trezentos e cinquenta e três')
  assert.equal(porExtenso(354), 'trezentos e cinquenta e quatro')
  assert.equal(porExtenso(355), 'trezentos e cinquenta e cinco')
  assert.equal(porExtenso(356), 'trezentos e cinquenta e seis')
  assert.equal(porExtenso(357), 'trezentos e cinquenta e sete')
  assert.equal(porExtenso(358), 'trezentos e cinquenta e oito')
  assert.equal(porExtenso(359), 'trezentos e cinquenta e nove')

  assert.equal(porExtenso(360), 'trezentos e sessenta')
  assert.equal(porExtenso(361), 'trezentos e sessenta e um')
  assert.equal(porExtenso(362), 'trezentos e sessenta e dois')
  assert.equal(porExtenso(363), 'trezentos e sessenta e três')
  assert.equal(porExtenso(364), 'trezentos e sessenta e quatro')
  assert.equal(porExtenso(365), 'trezentos e sessenta e cinco')
  assert.equal(porExtenso(366), 'trezentos e sessenta e seis')
  assert.equal(porExtenso(367), 'trezentos e sessenta e sete')
  assert.equal(porExtenso(368), 'trezentos e sessenta e oito')
  assert.equal(porExtenso(369), 'trezentos e sessenta e nove')

  assert.equal(porExtenso(370), 'trezentos e setenta')
  assert.equal(porExtenso(371), 'trezentos e setenta e um')
  assert.equal(porExtenso(372), 'trezentos e setenta e dois')
  assert.equal(porExtenso(373), 'trezentos e setenta e três')
  assert.equal(porExtenso(374), 'trezentos e setenta e quatro')
  assert.equal(porExtenso(375), 'trezentos e setenta e cinco')
  assert.equal(porExtenso(376), 'trezentos e setenta e seis')
  assert.equal(porExtenso(377), 'trezentos e setenta e sete')
  assert.equal(porExtenso(378), 'trezentos e setenta e oito')
  assert.equal(porExtenso(379), 'trezentos e setenta e nove')

  assert.equal(porExtenso(380), 'trezentos e oitenta')
  assert.equal(porExtenso(381), 'trezentos e oitenta e um')
  assert.equal(porExtenso(382), 'trezentos e oitenta e dois')
  assert.equal(porExtenso(383), 'trezentos e oitenta e três')
  assert.equal(porExtenso(384), 'trezentos e oitenta e quatro')
  assert.equal(porExtenso(385), 'trezentos e oitenta e cinco')
  assert.equal(porExtenso(386), 'trezentos e oitenta e seis')
  assert.equal(porExtenso(387), 'trezentos e oitenta e sete')
  assert.equal(porExtenso(388), 'trezentos e oitenta e oito')
  assert.equal(porExtenso(389), 'trezentos e oitenta e nove')

  assert.equal(porExtenso(390), 'trezentos e noventa')
  assert.equal(porExtenso(391), 'trezentos e noventa e um')
  assert.equal(porExtenso(392), 'trezentos e noventa e dois')
  assert.equal(porExtenso(393), 'trezentos e noventa e três')
  assert.equal(porExtenso(394), 'trezentos e noventa e quatro')
  assert.equal(porExtenso(395), 'trezentos e noventa e cinco')
  assert.equal(porExtenso(396), 'trezentos e noventa e seis')
  assert.equal(porExtenso(397), 'trezentos e noventa e sete')
  assert.equal(porExtenso(398), 'trezentos e noventa e oito')
  assert.equal(porExtenso(399), 'trezentos e noventa e nove')
})

it('trezentos+', () => {
  assert.equal(porExtenso.parse('trezentos'), '300')
  assert.equal(porExtenso.parse('trezentos e um'), '301')
  assert.equal(porExtenso.parse('trezentos e dois'), '302')
  assert.equal(porExtenso.parse('trezentos e três'), '303')
  assert.equal(porExtenso.parse('trezentos e quatro'), '304')
  assert.equal(porExtenso.parse('trezentos e cinco'), '305')
  assert.equal(porExtenso.parse('trezentos e seis'), '306')
  assert.equal(porExtenso.parse('trezentos e sete'), '307')
  assert.equal(porExtenso.parse('trezentos e oito'), '308')
  assert.equal(porExtenso.parse('trezentos e nove'), '309')

  assert.equal(porExtenso.parse('trezentos e dez'), '310')
  assert.equal(porExtenso.parse('trezentos e onze'), '311')
  assert.equal(porExtenso.parse('trezentos e doze'), '312')
  assert.equal(porExtenso.parse('trezentos e treze'), '313')
  assert.equal(porExtenso.parse('trezentos e quatorze'), '314')
  assert.equal(porExtenso.parse('trezentos e quinze'), '315')
  assert.equal(porExtenso.parse('trezentos e dezesseis'), '316')
  assert.equal(porExtenso.parse('trezentos e dezessete'), '317')
  assert.equal(porExtenso.parse('trezentos e dezoito'), '318')
  assert.equal(porExtenso.parse('trezentos e dezenove'), '319')

  assert.equal(porExtenso.parse('trezentos e vinte'), '320')
  assert.equal(porExtenso.parse('trezentos e vinte e um'), '321')
  assert.equal(porExtenso.parse('trezentos e vinte e dois'), '322')
  assert.equal(porExtenso.parse('trezentos e vinte e três'), '323')
  assert.equal(porExtenso.parse('trezentos e vinte e quatro'), '324')
  assert.equal(porExtenso.parse('trezentos e vinte e cinco'), '325')
  assert.equal(porExtenso.parse('trezentos e vinte e seis'), '326')
  assert.equal(porExtenso.parse('trezentos e vinte e sete'), '327')
  assert.equal(porExtenso.parse('trezentos e vinte e oito'), '328')
  assert.equal(porExtenso.parse('trezentos e vinte e nove'), '329')

  assert.equal(porExtenso.parse('trezentos e trinta'), '330')
  assert.equal(porExtenso.parse('trezentos e trinta e um'), '331')
  assert.equal(porExtenso.parse('trezentos e trinta e dois'), '332')
  assert.equal(porExtenso.parse('trezentos e trinta e três'), '333')
  assert.equal(porExtenso.parse('trezentos e trinta e quatro'), '334')
  assert.equal(porExtenso.parse('trezentos e trinta e cinco'), '335')
  assert.equal(porExtenso.parse('trezentos e trinta e seis'), '336')
  assert.equal(porExtenso.parse('trezentos e trinta e sete'), '337')
  assert.equal(porExtenso.parse('trezentos e trinta e oito'), '338')
  assert.equal(porExtenso.parse('trezentos e trinta e nove'), '339')

  assert.equal(porExtenso.parse('trezentos e quarenta'), '340')
  assert.equal(porExtenso.parse('trezentos e quarenta e um'), '341')
  assert.equal(porExtenso.parse('trezentos e quarenta e dois'), '342')
  assert.equal(porExtenso.parse('trezentos e quarenta e três'), '343')
  assert.equal(porExtenso.parse('trezentos e quarenta e quatro'), '344')
  assert.equal(porExtenso.parse('trezentos e quarenta e cinco'), '345')
  assert.equal(porExtenso.parse('trezentos e quarenta e seis'), '346')
  assert.equal(porExtenso.parse('trezentos e quarenta e sete'), '347')
  assert.equal(porExtenso.parse('trezentos e quarenta e oito'), '348')
  assert.equal(porExtenso.parse('trezentos e quarenta e nove'), '349')

  assert.equal(porExtenso.parse('trezentos e cinquenta'), '350')
  assert.equal(porExtenso.parse('trezentos e cinquenta e um'), '351')
  assert.equal(porExtenso.parse('trezentos e cinquenta e dois'), '352')
  assert.equal(porExtenso.parse('trezentos e cinquenta e três'), '353')
  assert.equal(porExtenso.parse('trezentos e cinquenta e quatro'), '354')
  assert.equal(porExtenso.parse('trezentos e cinquenta e cinco'), '355')
  assert.equal(porExtenso.parse('trezentos e cinquenta e seis'), '356')
  assert.equal(porExtenso.parse('trezentos e cinquenta e sete'), '357')
  assert.equal(porExtenso.parse('trezentos e cinquenta e oito'), '358')
  assert.equal(porExtenso.parse('trezentos e cinquenta e nove'), '359')

  assert.equal(porExtenso.parse('trezentos e sessenta'), '360')
  assert.equal(porExtenso.parse('trezentos e sessenta e um'), '361')
  assert.equal(porExtenso.parse('trezentos e sessenta e dois'), '362')
  assert.equal(porExtenso.parse('trezentos e sessenta e três'), '363')
  assert.equal(porExtenso.parse('trezentos e sessenta e quatro'), '364')
  assert.equal(porExtenso.parse('trezentos e sessenta e cinco'), '365')
  assert.equal(porExtenso.parse('trezentos e sessenta e seis'), '366')
  assert.equal(porExtenso.parse('trezentos e sessenta e sete'), '367')
  assert.equal(porExtenso.parse('trezentos e sessenta e oito'), '368')
  assert.equal(porExtenso.parse('trezentos e sessenta e nove'), '369')

  assert.equal(porExtenso.parse('trezentos e setenta'), '370')
  assert.equal(porExtenso.parse('trezentos e setenta e um'), '371')
  assert.equal(porExtenso.parse('trezentos e setenta e dois'), '372')
  assert.equal(porExtenso.parse('trezentos e setenta e três'), '373')
  assert.equal(porExtenso.parse('trezentos e setenta e quatro'), '374')
  assert.equal(porExtenso.parse('trezentos e setenta e cinco'), '375')
  assert.equal(porExtenso.parse('trezentos e setenta e seis'), '376')
  assert.equal(porExtenso.parse('trezentos e setenta e sete'), '377')
  assert.equal(porExtenso.parse('trezentos e setenta e oito'), '378')
  assert.equal(porExtenso.parse('trezentos e setenta e nove'), '379')

  assert.equal(porExtenso.parse('trezentos e oitenta'), '380')
  assert.equal(porExtenso.parse('trezentos e oitenta e um'), '381')
  assert.equal(porExtenso.parse('trezentos e oitenta e dois'), '382')
  assert.equal(porExtenso.parse('trezentos e oitenta e três'), '383')
  assert.equal(porExtenso.parse('trezentos e oitenta e quatro'), '384')
  assert.equal(porExtenso.parse('trezentos e oitenta e cinco'), '385')
  assert.equal(porExtenso.parse('trezentos e oitenta e seis'), '386')
  assert.equal(porExtenso.parse('trezentos e oitenta e sete'), '387')
  assert.equal(porExtenso.parse('trezentos e oitenta e oito'), '388')
  assert.equal(porExtenso.parse('trezentos e oitenta e nove'), '389')

  assert.equal(porExtenso.parse('trezentos e noventa'), '390')
  assert.equal(porExtenso.parse('trezentos e noventa e um'), '391')
  assert.equal(porExtenso.parse('trezentos e noventa e dois'), '392')
  assert.equal(porExtenso.parse('trezentos e noventa e três'), '393')
  assert.equal(porExtenso.parse('trezentos e noventa e quatro'), '394')
  assert.equal(porExtenso.parse('trezentos e noventa e cinco'), '395')
  assert.equal(porExtenso.parse('trezentos e noventa e seis'), '396')
  assert.equal(porExtenso.parse('trezentos e noventa e sete'), '397')
  assert.equal(porExtenso.parse('trezentos e noventa e oito'), '398')
  assert.equal(porExtenso.parse('trezentos e noventa e nove'), '399')
})

it('400+', () => {
  assert.equal(porExtenso(400), 'quatrocentos')
  assert.equal(porExtenso(401), 'quatrocentos e um')
  assert.equal(porExtenso(402), 'quatrocentos e dois')
  assert.equal(porExtenso(403), 'quatrocentos e três')
  assert.equal(porExtenso(404), 'quatrocentos e quatro')
  assert.equal(porExtenso(405), 'quatrocentos e cinco')
  assert.equal(porExtenso(406), 'quatrocentos e seis')
  assert.equal(porExtenso(407), 'quatrocentos e sete')
  assert.equal(porExtenso(408), 'quatrocentos e oito')
  assert.equal(porExtenso(409), 'quatrocentos e nove')

  assert.equal(porExtenso(410), 'quatrocentos e dez')
  assert.equal(porExtenso(411), 'quatrocentos e onze')
  assert.equal(porExtenso(412), 'quatrocentos e doze')
  assert.equal(porExtenso(413), 'quatrocentos e treze')
  assert.equal(porExtenso(414), 'quatrocentos e quatorze')
  assert.equal(porExtenso(415), 'quatrocentos e quinze')
  assert.equal(porExtenso(416), 'quatrocentos e dezesseis')
  assert.equal(porExtenso(417), 'quatrocentos e dezessete')
  assert.equal(porExtenso(418), 'quatrocentos e dezoito')
  assert.equal(porExtenso(419), 'quatrocentos e dezenove')

  assert.equal(porExtenso(420), 'quatrocentos e vinte')
  assert.equal(porExtenso(421), 'quatrocentos e vinte e um')
  assert.equal(porExtenso(422), 'quatrocentos e vinte e dois')
  assert.equal(porExtenso(423), 'quatrocentos e vinte e três')
  assert.equal(porExtenso(424), 'quatrocentos e vinte e quatro')
  assert.equal(porExtenso(425), 'quatrocentos e vinte e cinco')
  assert.equal(porExtenso(426), 'quatrocentos e vinte e seis')
  assert.equal(porExtenso(427), 'quatrocentos e vinte e sete')
  assert.equal(porExtenso(428), 'quatrocentos e vinte e oito')
  assert.equal(porExtenso(429), 'quatrocentos e vinte e nove')

  assert.equal(porExtenso(430), 'quatrocentos e trinta')
  assert.equal(porExtenso(431), 'quatrocentos e trinta e um')
  assert.equal(porExtenso(432), 'quatrocentos e trinta e dois')
  assert.equal(porExtenso(433), 'quatrocentos e trinta e três')
  assert.equal(porExtenso(434), 'quatrocentos e trinta e quatro')
  assert.equal(porExtenso(435), 'quatrocentos e trinta e cinco')
  assert.equal(porExtenso(436), 'quatrocentos e trinta e seis')
  assert.equal(porExtenso(437), 'quatrocentos e trinta e sete')
  assert.equal(porExtenso(438), 'quatrocentos e trinta e oito')
  assert.equal(porExtenso(439), 'quatrocentos e trinta e nove')

  assert.equal(porExtenso(440), 'quatrocentos e quarenta')
  assert.equal(porExtenso(441), 'quatrocentos e quarenta e um')
  assert.equal(porExtenso(442), 'quatrocentos e quarenta e dois')
  assert.equal(porExtenso(443), 'quatrocentos e quarenta e três')
  assert.equal(porExtenso(444), 'quatrocentos e quarenta e quatro')
  assert.equal(porExtenso(445), 'quatrocentos e quarenta e cinco')
  assert.equal(porExtenso(446), 'quatrocentos e quarenta e seis')
  assert.equal(porExtenso(447), 'quatrocentos e quarenta e sete')
  assert.equal(porExtenso(448), 'quatrocentos e quarenta e oito')
  assert.equal(porExtenso(449), 'quatrocentos e quarenta e nove')

  assert.equal(porExtenso(450), 'quatrocentos e cinquenta')
  assert.equal(porExtenso(451), 'quatrocentos e cinquenta e um')
  assert.equal(porExtenso(452), 'quatrocentos e cinquenta e dois')
  assert.equal(porExtenso(453), 'quatrocentos e cinquenta e três')
  assert.equal(porExtenso(454), 'quatrocentos e cinquenta e quatro')
  assert.equal(porExtenso(455), 'quatrocentos e cinquenta e cinco')
  assert.equal(porExtenso(456), 'quatrocentos e cinquenta e seis')
  assert.equal(porExtenso(457), 'quatrocentos e cinquenta e sete')
  assert.equal(porExtenso(458), 'quatrocentos e cinquenta e oito')
  assert.equal(porExtenso(459), 'quatrocentos e cinquenta e nove')

  assert.equal(porExtenso(460), 'quatrocentos e sessenta')
  assert.equal(porExtenso(461), 'quatrocentos e sessenta e um')
  assert.equal(porExtenso(462), 'quatrocentos e sessenta e dois')
  assert.equal(porExtenso(463), 'quatrocentos e sessenta e três')
  assert.equal(porExtenso(464), 'quatrocentos e sessenta e quatro')
  assert.equal(porExtenso(465), 'quatrocentos e sessenta e cinco')
  assert.equal(porExtenso(466), 'quatrocentos e sessenta e seis')
  assert.equal(porExtenso(467), 'quatrocentos e sessenta e sete')
  assert.equal(porExtenso(468), 'quatrocentos e sessenta e oito')
  assert.equal(porExtenso(469), 'quatrocentos e sessenta e nove')

  assert.equal(porExtenso(470), 'quatrocentos e setenta')
  assert.equal(porExtenso(471), 'quatrocentos e setenta e um')
  assert.equal(porExtenso(472), 'quatrocentos e setenta e dois')
  assert.equal(porExtenso(473), 'quatrocentos e setenta e três')
  assert.equal(porExtenso(474), 'quatrocentos e setenta e quatro')
  assert.equal(porExtenso(475), 'quatrocentos e setenta e cinco')
  assert.equal(porExtenso(476), 'quatrocentos e setenta e seis')
  assert.equal(porExtenso(477), 'quatrocentos e setenta e sete')
  assert.equal(porExtenso(478), 'quatrocentos e setenta e oito')
  assert.equal(porExtenso(479), 'quatrocentos e setenta e nove')

  assert.equal(porExtenso(480), 'quatrocentos e oitenta')
  assert.equal(porExtenso(481), 'quatrocentos e oitenta e um')
  assert.equal(porExtenso(482), 'quatrocentos e oitenta e dois')
  assert.equal(porExtenso(483), 'quatrocentos e oitenta e três')
  assert.equal(porExtenso(484), 'quatrocentos e oitenta e quatro')
  assert.equal(porExtenso(485), 'quatrocentos e oitenta e cinco')
  assert.equal(porExtenso(486), 'quatrocentos e oitenta e seis')
  assert.equal(porExtenso(487), 'quatrocentos e oitenta e sete')
  assert.equal(porExtenso(488), 'quatrocentos e oitenta e oito')
  assert.equal(porExtenso(489), 'quatrocentos e oitenta e nove')

  assert.equal(porExtenso(490), 'quatrocentos e noventa')
  assert.equal(porExtenso(491), 'quatrocentos e noventa e um')
  assert.equal(porExtenso(492), 'quatrocentos e noventa e dois')
  assert.equal(porExtenso(493), 'quatrocentos e noventa e três')
  assert.equal(porExtenso(494), 'quatrocentos e noventa e quatro')
  assert.equal(porExtenso(495), 'quatrocentos e noventa e cinco')
  assert.equal(porExtenso(496), 'quatrocentos e noventa e seis')
  assert.equal(porExtenso(497), 'quatrocentos e noventa e sete')
  assert.equal(porExtenso(498), 'quatrocentos e noventa e oito')
  assert.equal(porExtenso(499), 'quatrocentos e noventa e nove')
})

it('quatrocentos+', () => {
  assert.equal(porExtenso.parse('quatrocentos'), '400')
  assert.equal(porExtenso.parse('quatrocentos e um'), '401')
  assert.equal(porExtenso.parse('quatrocentos e dois'), '402')
  assert.equal(porExtenso.parse('quatrocentos e três'), '403')
  assert.equal(porExtenso.parse('quatrocentos e quatro'), '404')
  assert.equal(porExtenso.parse('quatrocentos e cinco'), '405')
  assert.equal(porExtenso.parse('quatrocentos e seis'), '406')
  assert.equal(porExtenso.parse('quatrocentos e sete'), '407')
  assert.equal(porExtenso.parse('quatrocentos e oito'), '408')
  assert.equal(porExtenso.parse('quatrocentos e nove'), '409')

  assert.equal(porExtenso.parse('quatrocentos e dez'), '410')
  assert.equal(porExtenso.parse('quatrocentos e onze'), '411')
  assert.equal(porExtenso.parse('quatrocentos e doze'), '412')
  assert.equal(porExtenso.parse('quatrocentos e treze'), '413')
  assert.equal(porExtenso.parse('quatrocentos e quatorze'), '414')
  assert.equal(porExtenso.parse('quatrocentos e quinze'), '415')
  assert.equal(porExtenso.parse('quatrocentos e dezesseis'), '416')
  assert.equal(porExtenso.parse('quatrocentos e dezessete'), '417')
  assert.equal(porExtenso.parse('quatrocentos e dezoito'), '418')
  assert.equal(porExtenso.parse('quatrocentos e dezenove'), '419')

  assert.equal(porExtenso.parse('quatrocentos e vinte'), '420')
  assert.equal(porExtenso.parse('quatrocentos e vinte e um'), '421')
  assert.equal(porExtenso.parse('quatrocentos e vinte e dois'), '422')
  assert.equal(porExtenso.parse('quatrocentos e vinte e três'), '423')
  assert.equal(porExtenso.parse('quatrocentos e vinte e quatro'), '424')
  assert.equal(porExtenso.parse('quatrocentos e vinte e cinco'), '425')
  assert.equal(porExtenso.parse('quatrocentos e vinte e seis'), '426')
  assert.equal(porExtenso.parse('quatrocentos e vinte e sete'), '427')
  assert.equal(porExtenso.parse('quatrocentos e vinte e oito'), '428')
  assert.equal(porExtenso.parse('quatrocentos e vinte e nove'), '429')

  assert.equal(porExtenso.parse('quatrocentos e trinta'), '430')
  assert.equal(porExtenso.parse('quatrocentos e trinta e um'), '431')
  assert.equal(porExtenso.parse('quatrocentos e trinta e dois'), '432')
  assert.equal(porExtenso.parse('quatrocentos e trinta e três'), '433')
  assert.equal(porExtenso.parse('quatrocentos e trinta e quatro'), '434')
  assert.equal(porExtenso.parse('quatrocentos e trinta e cinco'), '435')
  assert.equal(porExtenso.parse('quatrocentos e trinta e seis'), '436')
  assert.equal(porExtenso.parse('quatrocentos e trinta e sete'), '437')
  assert.equal(porExtenso.parse('quatrocentos e trinta e oito'), '438')
  assert.equal(porExtenso.parse('quatrocentos e trinta e nove'), '439')

  assert.equal(porExtenso.parse('quatrocentos e quarenta'), '440')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e um'), '441')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e dois'), '442')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e três'), '443')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e quatro'), '444')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e cinco'), '445')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e seis'), '446')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e sete'), '447')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e oito'), '448')
  assert.equal(porExtenso.parse('quatrocentos e quarenta e nove'), '449')

  assert.equal(porExtenso.parse('quatrocentos e cinquenta'), '450')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e um'), '451')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e dois'), '452')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e três'), '453')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e quatro'), '454')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e cinco'), '455')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e seis'), '456')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e sete'), '457')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e oito'), '458')
  assert.equal(porExtenso.parse('quatrocentos e cinquenta e nove'), '459')

  assert.equal(porExtenso.parse('quatrocentos e sessenta'), '460')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e um'), '461')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e dois'), '462')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e três'), '463')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e quatro'), '464')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e cinco'), '465')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e seis'), '466')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e sete'), '467')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e oito'), '468')
  assert.equal(porExtenso.parse('quatrocentos e sessenta e nove'), '469')

  assert.equal(porExtenso.parse('quatrocentos e setenta'), '470')
  assert.equal(porExtenso.parse('quatrocentos e setenta e um'), '471')
  assert.equal(porExtenso.parse('quatrocentos e setenta e dois'), '472')
  assert.equal(porExtenso.parse('quatrocentos e setenta e três'), '473')
  assert.equal(porExtenso.parse('quatrocentos e setenta e quatro'), '474')
  assert.equal(porExtenso.parse('quatrocentos e setenta e cinco'), '475')
  assert.equal(porExtenso.parse('quatrocentos e setenta e seis'), '476')
  assert.equal(porExtenso.parse('quatrocentos e setenta e sete'), '477')
  assert.equal(porExtenso.parse('quatrocentos e setenta e oito'), '478')
  assert.equal(porExtenso.parse('quatrocentos e setenta e nove'), '479')

  assert.equal(porExtenso.parse('quatrocentos e oitenta'), '480')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e um'), '481')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e dois'), '482')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e três'), '483')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e quatro'), '484')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e cinco'), '485')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e seis'), '486')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e sete'), '487')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e oito'), '488')
  assert.equal(porExtenso.parse('quatrocentos e oitenta e nove'), '489')

  assert.equal(porExtenso.parse('quatrocentos e noventa'), '490')
  assert.equal(porExtenso.parse('quatrocentos e noventa e um'), '491')
  assert.equal(porExtenso.parse('quatrocentos e noventa e dois'), '492')
  assert.equal(porExtenso.parse('quatrocentos e noventa e três'), '493')
  assert.equal(porExtenso.parse('quatrocentos e noventa e quatro'), '494')
  assert.equal(porExtenso.parse('quatrocentos e noventa e cinco'), '495')
  assert.equal(porExtenso.parse('quatrocentos e noventa e seis'), '496')
  assert.equal(porExtenso.parse('quatrocentos e noventa e sete'), '497')
  assert.equal(porExtenso.parse('quatrocentos e noventa e oito'), '498')
  assert.equal(porExtenso.parse('quatrocentos e noventa e nove'), '499')
})

it('500+', () => {
  assert.equal(porExtenso(500), 'quinhentos')
  assert.equal(porExtenso(501), 'quinhentos e um')
  assert.equal(porExtenso(502), 'quinhentos e dois')
  assert.equal(porExtenso(503), 'quinhentos e três')
  assert.equal(porExtenso(504), 'quinhentos e quatro')
  assert.equal(porExtenso(505), 'quinhentos e cinco')
  assert.equal(porExtenso(506), 'quinhentos e seis')
  assert.equal(porExtenso(507), 'quinhentos e sete')
  assert.equal(porExtenso(508), 'quinhentos e oito')
  assert.equal(porExtenso(509), 'quinhentos e nove')

  assert.equal(porExtenso(510), 'quinhentos e dez')
  assert.equal(porExtenso(511), 'quinhentos e onze')
  assert.equal(porExtenso(512), 'quinhentos e doze')
  assert.equal(porExtenso(513), 'quinhentos e treze')
  assert.equal(porExtenso(514), 'quinhentos e quatorze')
  assert.equal(porExtenso(515), 'quinhentos e quinze')
  assert.equal(porExtenso(516), 'quinhentos e dezesseis')
  assert.equal(porExtenso(517), 'quinhentos e dezessete')
  assert.equal(porExtenso(518), 'quinhentos e dezoito')
  assert.equal(porExtenso(519), 'quinhentos e dezenove')

  assert.equal(porExtenso(520), 'quinhentos e vinte')
  assert.equal(porExtenso(521), 'quinhentos e vinte e um')
  assert.equal(porExtenso(522), 'quinhentos e vinte e dois')
  assert.equal(porExtenso(523), 'quinhentos e vinte e três')
  assert.equal(porExtenso(524), 'quinhentos e vinte e quatro')
  assert.equal(porExtenso(525), 'quinhentos e vinte e cinco')
  assert.equal(porExtenso(526), 'quinhentos e vinte e seis')
  assert.equal(porExtenso(527), 'quinhentos e vinte e sete')
  assert.equal(porExtenso(528), 'quinhentos e vinte e oito')
  assert.equal(porExtenso(529), 'quinhentos e vinte e nove')

  assert.equal(porExtenso(530), 'quinhentos e trinta')
  assert.equal(porExtenso(531), 'quinhentos e trinta e um')
  assert.equal(porExtenso(532), 'quinhentos e trinta e dois')
  assert.equal(porExtenso(533), 'quinhentos e trinta e três')
  assert.equal(porExtenso(534), 'quinhentos e trinta e quatro')
  assert.equal(porExtenso(535), 'quinhentos e trinta e cinco')
  assert.equal(porExtenso(536), 'quinhentos e trinta e seis')
  assert.equal(porExtenso(537), 'quinhentos e trinta e sete')
  assert.equal(porExtenso(538), 'quinhentos e trinta e oito')
  assert.equal(porExtenso(539), 'quinhentos e trinta e nove')

  assert.equal(porExtenso(540), 'quinhentos e quarenta')
  assert.equal(porExtenso(541), 'quinhentos e quarenta e um')
  assert.equal(porExtenso(542), 'quinhentos e quarenta e dois')
  assert.equal(porExtenso(543), 'quinhentos e quarenta e três')
  assert.equal(porExtenso(544), 'quinhentos e quarenta e quatro')
  assert.equal(porExtenso(545), 'quinhentos e quarenta e cinco')
  assert.equal(porExtenso(546), 'quinhentos e quarenta e seis')
  assert.equal(porExtenso(547), 'quinhentos e quarenta e sete')
  assert.equal(porExtenso(548), 'quinhentos e quarenta e oito')
  assert.equal(porExtenso(549), 'quinhentos e quarenta e nove')

  assert.equal(porExtenso(550), 'quinhentos e cinquenta')
  assert.equal(porExtenso(551), 'quinhentos e cinquenta e um')
  assert.equal(porExtenso(552), 'quinhentos e cinquenta e dois')
  assert.equal(porExtenso(553), 'quinhentos e cinquenta e três')
  assert.equal(porExtenso(554), 'quinhentos e cinquenta e quatro')
  assert.equal(porExtenso(555), 'quinhentos e cinquenta e cinco')
  assert.equal(porExtenso(556), 'quinhentos e cinquenta e seis')
  assert.equal(porExtenso(557), 'quinhentos e cinquenta e sete')
  assert.equal(porExtenso(558), 'quinhentos e cinquenta e oito')
  assert.equal(porExtenso(559), 'quinhentos e cinquenta e nove')

  assert.equal(porExtenso(560), 'quinhentos e sessenta')
  assert.equal(porExtenso(561), 'quinhentos e sessenta e um')
  assert.equal(porExtenso(562), 'quinhentos e sessenta e dois')
  assert.equal(porExtenso(563), 'quinhentos e sessenta e três')
  assert.equal(porExtenso(564), 'quinhentos e sessenta e quatro')
  assert.equal(porExtenso(565), 'quinhentos e sessenta e cinco')
  assert.equal(porExtenso(566), 'quinhentos e sessenta e seis')
  assert.equal(porExtenso(567), 'quinhentos e sessenta e sete')
  assert.equal(porExtenso(568), 'quinhentos e sessenta e oito')
  assert.equal(porExtenso(569), 'quinhentos e sessenta e nove')

  assert.equal(porExtenso(570), 'quinhentos e setenta')
  assert.equal(porExtenso(571), 'quinhentos e setenta e um')
  assert.equal(porExtenso(572), 'quinhentos e setenta e dois')
  assert.equal(porExtenso(573), 'quinhentos e setenta e três')
  assert.equal(porExtenso(574), 'quinhentos e setenta e quatro')
  assert.equal(porExtenso(575), 'quinhentos e setenta e cinco')
  assert.equal(porExtenso(576), 'quinhentos e setenta e seis')
  assert.equal(porExtenso(577), 'quinhentos e setenta e sete')
  assert.equal(porExtenso(578), 'quinhentos e setenta e oito')
  assert.equal(porExtenso(579), 'quinhentos e setenta e nove')

  assert.equal(porExtenso(580), 'quinhentos e oitenta')
  assert.equal(porExtenso(581), 'quinhentos e oitenta e um')
  assert.equal(porExtenso(582), 'quinhentos e oitenta e dois')
  assert.equal(porExtenso(583), 'quinhentos e oitenta e três')
  assert.equal(porExtenso(584), 'quinhentos e oitenta e quatro')
  assert.equal(porExtenso(585), 'quinhentos e oitenta e cinco')
  assert.equal(porExtenso(586), 'quinhentos e oitenta e seis')
  assert.equal(porExtenso(587), 'quinhentos e oitenta e sete')
  assert.equal(porExtenso(588), 'quinhentos e oitenta e oito')
  assert.equal(porExtenso(589), 'quinhentos e oitenta e nove')

  assert.equal(porExtenso(590), 'quinhentos e noventa')
  assert.equal(porExtenso(591), 'quinhentos e noventa e um')
  assert.equal(porExtenso(592), 'quinhentos e noventa e dois')
  assert.equal(porExtenso(593), 'quinhentos e noventa e três')
  assert.equal(porExtenso(594), 'quinhentos e noventa e quatro')
  assert.equal(porExtenso(595), 'quinhentos e noventa e cinco')
  assert.equal(porExtenso(596), 'quinhentos e noventa e seis')
  assert.equal(porExtenso(597), 'quinhentos e noventa e sete')
  assert.equal(porExtenso(598), 'quinhentos e noventa e oito')
  assert.equal(porExtenso(599), 'quinhentos e noventa e nove')
})

it('quinhentos+', () => {
  assert.equal(porExtenso.parse('quinhentos'), '500')
  assert.equal(porExtenso.parse('quinhentos e um'), '501')
  assert.equal(porExtenso.parse('quinhentos e dois'), '502')
  assert.equal(porExtenso.parse('quinhentos e três'), '503')
  assert.equal(porExtenso.parse('quinhentos e quatro'), '504')
  assert.equal(porExtenso.parse('quinhentos e cinco'), '505')
  assert.equal(porExtenso.parse('quinhentos e seis'), '506')
  assert.equal(porExtenso.parse('quinhentos e sete'), '507')
  assert.equal(porExtenso.parse('quinhentos e oito'), '508')
  assert.equal(porExtenso.parse('quinhentos e nove'), '509')

  assert.equal(porExtenso.parse('quinhentos e dez'), '510')
  assert.equal(porExtenso.parse('quinhentos e onze'), '511')
  assert.equal(porExtenso.parse('quinhentos e doze'), '512')
  assert.equal(porExtenso.parse('quinhentos e treze'), '513')
  assert.equal(porExtenso.parse('quinhentos e quatorze'), '514')
  assert.equal(porExtenso.parse('quinhentos e quinze'), '515')
  assert.equal(porExtenso.parse('quinhentos e dezesseis'), '516')
  assert.equal(porExtenso.parse('quinhentos e dezessete'), '517')
  assert.equal(porExtenso.parse('quinhentos e dezoito'), '518')
  assert.equal(porExtenso.parse('quinhentos e dezenove'), '519')

  assert.equal(porExtenso.parse('quinhentos e vinte'), '520')
  assert.equal(porExtenso.parse('quinhentos e vinte e um'), '521')
  assert.equal(porExtenso.parse('quinhentos e vinte e dois'), '522')
  assert.equal(porExtenso.parse('quinhentos e vinte e três'), '523')
  assert.equal(porExtenso.parse('quinhentos e vinte e quatro'), '524')
  assert.equal(porExtenso.parse('quinhentos e vinte e cinco'), '525')
  assert.equal(porExtenso.parse('quinhentos e vinte e seis'), '526')
  assert.equal(porExtenso.parse('quinhentos e vinte e sete'), '527')
  assert.equal(porExtenso.parse('quinhentos e vinte e oito'), '528')
  assert.equal(porExtenso.parse('quinhentos e vinte e nove'), '529')

  assert.equal(porExtenso.parse('quinhentos e trinta'), '530')
  assert.equal(porExtenso.parse('quinhentos e trinta e um'), '531')
  assert.equal(porExtenso.parse('quinhentos e trinta e dois'), '532')
  assert.equal(porExtenso.parse('quinhentos e trinta e três'), '533')
  assert.equal(porExtenso.parse('quinhentos e trinta e quatro'), '534')
  assert.equal(porExtenso.parse('quinhentos e trinta e cinco'), '535')
  assert.equal(porExtenso.parse('quinhentos e trinta e seis'), '536')
  assert.equal(porExtenso.parse('quinhentos e trinta e sete'), '537')
  assert.equal(porExtenso.parse('quinhentos e trinta e oito'), '538')
  assert.equal(porExtenso.parse('quinhentos e trinta e nove'), '539')

  assert.equal(porExtenso.parse('quinhentos e quarenta'), '540')
  assert.equal(porExtenso.parse('quinhentos e quarenta e um'), '541')
  assert.equal(porExtenso.parse('quinhentos e quarenta e dois'), '542')
  assert.equal(porExtenso.parse('quinhentos e quarenta e três'), '543')
  assert.equal(porExtenso.parse('quinhentos e quarenta e quatro'), '544')
  assert.equal(porExtenso.parse('quinhentos e quarenta e cinco'), '545')
  assert.equal(porExtenso.parse('quinhentos e quarenta e seis'), '546')
  assert.equal(porExtenso.parse('quinhentos e quarenta e sete'), '547')
  assert.equal(porExtenso.parse('quinhentos e quarenta e oito'), '548')
  assert.equal(porExtenso.parse('quinhentos e quarenta e nove'), '549')

  assert.equal(porExtenso.parse('quinhentos e cinquenta'), '550')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e um'), '551')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e dois'), '552')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e três'), '553')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e quatro'), '554')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e cinco'), '555')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e seis'), '556')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e sete'), '557')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e oito'), '558')
  assert.equal(porExtenso.parse('quinhentos e cinquenta e nove'), '559')

  assert.equal(porExtenso.parse('quinhentos e sessenta'), '560')
  assert.equal(porExtenso.parse('quinhentos e sessenta e um'), '561')
  assert.equal(porExtenso.parse('quinhentos e sessenta e dois'), '562')
  assert.equal(porExtenso.parse('quinhentos e sessenta e três'), '563')
  assert.equal(porExtenso.parse('quinhentos e sessenta e quatro'), '564')
  assert.equal(porExtenso.parse('quinhentos e sessenta e cinco'), '565')
  assert.equal(porExtenso.parse('quinhentos e sessenta e seis'), '566')
  assert.equal(porExtenso.parse('quinhentos e sessenta e sete'), '567')
  assert.equal(porExtenso.parse('quinhentos e sessenta e oito'), '568')
  assert.equal(porExtenso.parse('quinhentos e sessenta e nove'), '569')

  assert.equal(porExtenso.parse('quinhentos e setenta'), '570')
  assert.equal(porExtenso.parse('quinhentos e setenta e um'), '571')
  assert.equal(porExtenso.parse('quinhentos e setenta e dois'), '572')
  assert.equal(porExtenso.parse('quinhentos e setenta e três'), '573')
  assert.equal(porExtenso.parse('quinhentos e setenta e quatro'), '574')
  assert.equal(porExtenso.parse('quinhentos e setenta e cinco'), '575')
  assert.equal(porExtenso.parse('quinhentos e setenta e seis'), '576')
  assert.equal(porExtenso.parse('quinhentos e setenta e sete'), '577')
  assert.equal(porExtenso.parse('quinhentos e setenta e oito'), '578')
  assert.equal(porExtenso.parse('quinhentos e setenta e nove'), '579')

  assert.equal(porExtenso.parse('quinhentos e oitenta'), '580')
  assert.equal(porExtenso.parse('quinhentos e oitenta e um'), '581')
  assert.equal(porExtenso.parse('quinhentos e oitenta e dois'), '582')
  assert.equal(porExtenso.parse('quinhentos e oitenta e três'), '583')
  assert.equal(porExtenso.parse('quinhentos e oitenta e quatro'), '584')
  assert.equal(porExtenso.parse('quinhentos e oitenta e cinco'), '585')
  assert.equal(porExtenso.parse('quinhentos e oitenta e seis'), '586')
  assert.equal(porExtenso.parse('quinhentos e oitenta e sete'), '587')
  assert.equal(porExtenso.parse('quinhentos e oitenta e oito'), '588')
  assert.equal(porExtenso.parse('quinhentos e oitenta e nove'), '589')

  assert.equal(porExtenso.parse('quinhentos e noventa'), '590')
  assert.equal(porExtenso.parse('quinhentos e noventa e um'), '591')
  assert.equal(porExtenso.parse('quinhentos e noventa e dois'), '592')
  assert.equal(porExtenso.parse('quinhentos e noventa e três'), '593')
  assert.equal(porExtenso.parse('quinhentos e noventa e quatro'), '594')
  assert.equal(porExtenso.parse('quinhentos e noventa e cinco'), '595')
  assert.equal(porExtenso.parse('quinhentos e noventa e seis'), '596')
  assert.equal(porExtenso.parse('quinhentos e noventa e sete'), '597')
  assert.equal(porExtenso.parse('quinhentos e noventa e oito'), '598')
  assert.equal(porExtenso.parse('quinhentos e noventa e nove'), '599')
})

it('600+', () => {
  assert.equal(porExtenso(600), 'seiscentos')
  assert.equal(porExtenso(601), 'seiscentos e um')
  assert.equal(porExtenso(602), 'seiscentos e dois')
  assert.equal(porExtenso(603), 'seiscentos e três')
  assert.equal(porExtenso(604), 'seiscentos e quatro')
  assert.equal(porExtenso(605), 'seiscentos e cinco')
  assert.equal(porExtenso(606), 'seiscentos e seis')
  assert.equal(porExtenso(607), 'seiscentos e sete')
  assert.equal(porExtenso(608), 'seiscentos e oito')
  assert.equal(porExtenso(609), 'seiscentos e nove')

  assert.equal(porExtenso(610), 'seiscentos e dez')
  assert.equal(porExtenso(611), 'seiscentos e onze')
  assert.equal(porExtenso(612), 'seiscentos e doze')
  assert.equal(porExtenso(613), 'seiscentos e treze')
  assert.equal(porExtenso(614), 'seiscentos e quatorze')
  assert.equal(porExtenso(615), 'seiscentos e quinze')
  assert.equal(porExtenso(616), 'seiscentos e dezesseis')
  assert.equal(porExtenso(617), 'seiscentos e dezessete')
  assert.equal(porExtenso(618), 'seiscentos e dezoito')
  assert.equal(porExtenso(619), 'seiscentos e dezenove')

  assert.equal(porExtenso(620), 'seiscentos e vinte')
  assert.equal(porExtenso(621), 'seiscentos e vinte e um')
  assert.equal(porExtenso(622), 'seiscentos e vinte e dois')
  assert.equal(porExtenso(623), 'seiscentos e vinte e três')
  assert.equal(porExtenso(624), 'seiscentos e vinte e quatro')
  assert.equal(porExtenso(625), 'seiscentos e vinte e cinco')
  assert.equal(porExtenso(626), 'seiscentos e vinte e seis')
  assert.equal(porExtenso(627), 'seiscentos e vinte e sete')
  assert.equal(porExtenso(628), 'seiscentos e vinte e oito')
  assert.equal(porExtenso(629), 'seiscentos e vinte e nove')

  assert.equal(porExtenso(630), 'seiscentos e trinta')
  assert.equal(porExtenso(631), 'seiscentos e trinta e um')
  assert.equal(porExtenso(632), 'seiscentos e trinta e dois')
  assert.equal(porExtenso(633), 'seiscentos e trinta e três')
  assert.equal(porExtenso(634), 'seiscentos e trinta e quatro')
  assert.equal(porExtenso(635), 'seiscentos e trinta e cinco')
  assert.equal(porExtenso(636), 'seiscentos e trinta e seis')
  assert.equal(porExtenso(637), 'seiscentos e trinta e sete')
  assert.equal(porExtenso(638), 'seiscentos e trinta e oito')
  assert.equal(porExtenso(639), 'seiscentos e trinta e nove')

  assert.equal(porExtenso(640), 'seiscentos e quarenta')
  assert.equal(porExtenso(641), 'seiscentos e quarenta e um')
  assert.equal(porExtenso(642), 'seiscentos e quarenta e dois')
  assert.equal(porExtenso(643), 'seiscentos e quarenta e três')
  assert.equal(porExtenso(644), 'seiscentos e quarenta e quatro')
  assert.equal(porExtenso(645), 'seiscentos e quarenta e cinco')
  assert.equal(porExtenso(646), 'seiscentos e quarenta e seis')
  assert.equal(porExtenso(647), 'seiscentos e quarenta e sete')
  assert.equal(porExtenso(648), 'seiscentos e quarenta e oito')
  assert.equal(porExtenso(649), 'seiscentos e quarenta e nove')

  assert.equal(porExtenso(650), 'seiscentos e cinquenta')
  assert.equal(porExtenso(651), 'seiscentos e cinquenta e um')
  assert.equal(porExtenso(652), 'seiscentos e cinquenta e dois')
  assert.equal(porExtenso(653), 'seiscentos e cinquenta e três')
  assert.equal(porExtenso(654), 'seiscentos e cinquenta e quatro')
  assert.equal(porExtenso(655), 'seiscentos e cinquenta e cinco')
  assert.equal(porExtenso(656), 'seiscentos e cinquenta e seis')
  assert.equal(porExtenso(657), 'seiscentos e cinquenta e sete')
  assert.equal(porExtenso(658), 'seiscentos e cinquenta e oito')
  assert.equal(porExtenso(659), 'seiscentos e cinquenta e nove')

  assert.equal(porExtenso(660), 'seiscentos e sessenta')
  assert.equal(porExtenso(661), 'seiscentos e sessenta e um')
  assert.equal(porExtenso(662), 'seiscentos e sessenta e dois')
  assert.equal(porExtenso(663), 'seiscentos e sessenta e três')
  assert.equal(porExtenso(664), 'seiscentos e sessenta e quatro')
  assert.equal(porExtenso(665), 'seiscentos e sessenta e cinco')
  assert.equal(porExtenso(666), 'seiscentos e sessenta e seis')
  assert.equal(porExtenso(667), 'seiscentos e sessenta e sete')
  assert.equal(porExtenso(668), 'seiscentos e sessenta e oito')
  assert.equal(porExtenso(669), 'seiscentos e sessenta e nove')

  assert.equal(porExtenso(670), 'seiscentos e setenta')
  assert.equal(porExtenso(671), 'seiscentos e setenta e um')
  assert.equal(porExtenso(672), 'seiscentos e setenta e dois')
  assert.equal(porExtenso(673), 'seiscentos e setenta e três')
  assert.equal(porExtenso(674), 'seiscentos e setenta e quatro')
  assert.equal(porExtenso(675), 'seiscentos e setenta e cinco')
  assert.equal(porExtenso(676), 'seiscentos e setenta e seis')
  assert.equal(porExtenso(677), 'seiscentos e setenta e sete')
  assert.equal(porExtenso(678), 'seiscentos e setenta e oito')
  assert.equal(porExtenso(679), 'seiscentos e setenta e nove')

  assert.equal(porExtenso(680), 'seiscentos e oitenta')
  assert.equal(porExtenso(681), 'seiscentos e oitenta e um')
  assert.equal(porExtenso(682), 'seiscentos e oitenta e dois')
  assert.equal(porExtenso(683), 'seiscentos e oitenta e três')
  assert.equal(porExtenso(684), 'seiscentos e oitenta e quatro')
  assert.equal(porExtenso(685), 'seiscentos e oitenta e cinco')
  assert.equal(porExtenso(686), 'seiscentos e oitenta e seis')
  assert.equal(porExtenso(687), 'seiscentos e oitenta e sete')
  assert.equal(porExtenso(688), 'seiscentos e oitenta e oito')
  assert.equal(porExtenso(689), 'seiscentos e oitenta e nove')

  assert.equal(porExtenso(690), 'seiscentos e noventa')
  assert.equal(porExtenso(691), 'seiscentos e noventa e um')
  assert.equal(porExtenso(692), 'seiscentos e noventa e dois')
  assert.equal(porExtenso(693), 'seiscentos e noventa e três')
  assert.equal(porExtenso(694), 'seiscentos e noventa e quatro')
  assert.equal(porExtenso(695), 'seiscentos e noventa e cinco')
  assert.equal(porExtenso(696), 'seiscentos e noventa e seis')
  assert.equal(porExtenso(697), 'seiscentos e noventa e sete')
  assert.equal(porExtenso(698), 'seiscentos e noventa e oito')
  assert.equal(porExtenso(699), 'seiscentos e noventa e nove')
})

it('seiscentos+', () => {
  assert.equal(porExtenso.parse('seiscentos'), '600')
  assert.equal(porExtenso.parse('seiscentos e um'), '601')
  assert.equal(porExtenso.parse('seiscentos e dois'), '602')
  assert.equal(porExtenso.parse('seiscentos e três'), '603')
  assert.equal(porExtenso.parse('seiscentos e quatro'), '604')
  assert.equal(porExtenso.parse('seiscentos e cinco'), '605')
  assert.equal(porExtenso.parse('seiscentos e seis'), '606')
  assert.equal(porExtenso.parse('seiscentos e sete'), '607')
  assert.equal(porExtenso.parse('seiscentos e oito'), '608')
  assert.equal(porExtenso.parse('seiscentos e nove'), '609')

  assert.equal(porExtenso.parse('seiscentos e dez'), '610')
  assert.equal(porExtenso.parse('seiscentos e onze'), '611')
  assert.equal(porExtenso.parse('seiscentos e doze'), '612')
  assert.equal(porExtenso.parse('seiscentos e treze'), '613')
  assert.equal(porExtenso.parse('seiscentos e quatorze'), '614')
  assert.equal(porExtenso.parse('seiscentos e quinze'), '615')
  assert.equal(porExtenso.parse('seiscentos e dezesseis'), '616')
  assert.equal(porExtenso.parse('seiscentos e dezessete'), '617')
  assert.equal(porExtenso.parse('seiscentos e dezoito'), '618')
  assert.equal(porExtenso.parse('seiscentos e dezenove'), '619')

  assert.equal(porExtenso.parse('seiscentos e vinte'), '620')
  assert.equal(porExtenso.parse('seiscentos e vinte e um'), '621')
  assert.equal(porExtenso.parse('seiscentos e vinte e dois'), '622')
  assert.equal(porExtenso.parse('seiscentos e vinte e três'), '623')
  assert.equal(porExtenso.parse('seiscentos e vinte e quatro'), '624')
  assert.equal(porExtenso.parse('seiscentos e vinte e cinco'), '625')
  assert.equal(porExtenso.parse('seiscentos e vinte e seis'), '626')
  assert.equal(porExtenso.parse('seiscentos e vinte e sete'), '627')
  assert.equal(porExtenso.parse('seiscentos e vinte e oito'), '628')
  assert.equal(porExtenso.parse('seiscentos e vinte e nove'), '629')

  assert.equal(porExtenso.parse('seiscentos e trinta'), '630')
  assert.equal(porExtenso.parse('seiscentos e trinta e um'), '631')
  assert.equal(porExtenso.parse('seiscentos e trinta e dois'), '632')
  assert.equal(porExtenso.parse('seiscentos e trinta e três'), '633')
  assert.equal(porExtenso.parse('seiscentos e trinta e quatro'), '634')
  assert.equal(porExtenso.parse('seiscentos e trinta e cinco'), '635')
  assert.equal(porExtenso.parse('seiscentos e trinta e seis'), '636')
  assert.equal(porExtenso.parse('seiscentos e trinta e sete'), '637')
  assert.equal(porExtenso.parse('seiscentos e trinta e oito'), '638')
  assert.equal(porExtenso.parse('seiscentos e trinta e nove'), '639')

  assert.equal(porExtenso.parse('seiscentos e quarenta'), '640')
  assert.equal(porExtenso.parse('seiscentos e quarenta e um'), '641')
  assert.equal(porExtenso.parse('seiscentos e quarenta e dois'), '642')
  assert.equal(porExtenso.parse('seiscentos e quarenta e três'), '643')
  assert.equal(porExtenso.parse('seiscentos e quarenta e quatro'), '644')
  assert.equal(porExtenso.parse('seiscentos e quarenta e cinco'), '645')
  assert.equal(porExtenso.parse('seiscentos e quarenta e seis'), '646')
  assert.equal(porExtenso.parse('seiscentos e quarenta e sete'), '647')
  assert.equal(porExtenso.parse('seiscentos e quarenta e oito'), '648')
  assert.equal(porExtenso.parse('seiscentos e quarenta e nove'), '649')

  assert.equal(porExtenso.parse('seiscentos e cinquenta'), '650')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e um'), '651')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e dois'), '652')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e três'), '653')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e quatro'), '654')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e cinco'), '655')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e seis'), '656')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e sete'), '657')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e oito'), '658')
  assert.equal(porExtenso.parse('seiscentos e cinquenta e nove'), '659')

  assert.equal(porExtenso.parse('seiscentos e sessenta'), '660')
  assert.equal(porExtenso.parse('seiscentos e sessenta e um'), '661')
  assert.equal(porExtenso.parse('seiscentos e sessenta e dois'), '662')
  assert.equal(porExtenso.parse('seiscentos e sessenta e três'), '663')
  assert.equal(porExtenso.parse('seiscentos e sessenta e quatro'), '664')
  assert.equal(porExtenso.parse('seiscentos e sessenta e cinco'), '665')
  assert.equal(porExtenso.parse('seiscentos e sessenta e seis'), '666')
  assert.equal(porExtenso.parse('seiscentos e sessenta e sete'), '667')
  assert.equal(porExtenso.parse('seiscentos e sessenta e oito'), '668')
  assert.equal(porExtenso.parse('seiscentos e sessenta e nove'), '669')

  assert.equal(porExtenso.parse('seiscentos e setenta'), '670')
  assert.equal(porExtenso.parse('seiscentos e setenta e um'), '671')
  assert.equal(porExtenso.parse('seiscentos e setenta e dois'), '672')
  assert.equal(porExtenso.parse('seiscentos e setenta e três'), '673')
  assert.equal(porExtenso.parse('seiscentos e setenta e quatro'), '674')
  assert.equal(porExtenso.parse('seiscentos e setenta e cinco'), '675')
  assert.equal(porExtenso.parse('seiscentos e setenta e seis'), '676')
  assert.equal(porExtenso.parse('seiscentos e setenta e sete'), '677')
  assert.equal(porExtenso.parse('seiscentos e setenta e oito'), '678')
  assert.equal(porExtenso.parse('seiscentos e setenta e nove'), '679')

  assert.equal(porExtenso.parse('seiscentos e oitenta'), '680')
  assert.equal(porExtenso.parse('seiscentos e oitenta e um'), '681')
  assert.equal(porExtenso.parse('seiscentos e oitenta e dois'), '682')
  assert.equal(porExtenso.parse('seiscentos e oitenta e três'), '683')
  assert.equal(porExtenso.parse('seiscentos e oitenta e quatro'), '684')
  assert.equal(porExtenso.parse('seiscentos e oitenta e cinco'), '685')
  assert.equal(porExtenso.parse('seiscentos e oitenta e seis'), '686')
  assert.equal(porExtenso.parse('seiscentos e oitenta e sete'), '687')
  assert.equal(porExtenso.parse('seiscentos e oitenta e oito'), '688')
  assert.equal(porExtenso.parse('seiscentos e oitenta e nove'), '689')

  assert.equal(porExtenso.parse('seiscentos e noventa'), '690')
  assert.equal(porExtenso.parse('seiscentos e noventa e um'), '691')
  assert.equal(porExtenso.parse('seiscentos e noventa e dois'), '692')
  assert.equal(porExtenso.parse('seiscentos e noventa e três'), '693')
  assert.equal(porExtenso.parse('seiscentos e noventa e quatro'), '694')
  assert.equal(porExtenso.parse('seiscentos e noventa e cinco'), '695')
  assert.equal(porExtenso.parse('seiscentos e noventa e seis'), '696')
  assert.equal(porExtenso.parse('seiscentos e noventa e sete'), '697')
  assert.equal(porExtenso.parse('seiscentos e noventa e oito'), '698')
  assert.equal(porExtenso.parse('seiscentos e noventa e nove'), '699')
})

it('700+', () => {
  assert.equal(porExtenso(700), 'setecentos')
  assert.equal(porExtenso(701), 'setecentos e um')
  assert.equal(porExtenso(702), 'setecentos e dois')
  assert.equal(porExtenso(703), 'setecentos e três')
  assert.equal(porExtenso(704), 'setecentos e quatro')
  assert.equal(porExtenso(705), 'setecentos e cinco')
  assert.equal(porExtenso(706), 'setecentos e seis')
  assert.equal(porExtenso(707), 'setecentos e sete')
  assert.equal(porExtenso(708), 'setecentos e oito')
  assert.equal(porExtenso(709), 'setecentos e nove')

  assert.equal(porExtenso(710), 'setecentos e dez')
  assert.equal(porExtenso(711), 'setecentos e onze')
  assert.equal(porExtenso(712), 'setecentos e doze')
  assert.equal(porExtenso(713), 'setecentos e treze')
  assert.equal(porExtenso(714), 'setecentos e quatorze')
  assert.equal(porExtenso(715), 'setecentos e quinze')
  assert.equal(porExtenso(716), 'setecentos e dezesseis')
  assert.equal(porExtenso(717), 'setecentos e dezessete')
  assert.equal(porExtenso(718), 'setecentos e dezoito')
  assert.equal(porExtenso(719), 'setecentos e dezenove')

  assert.equal(porExtenso(720), 'setecentos e vinte')
  assert.equal(porExtenso(721), 'setecentos e vinte e um')
  assert.equal(porExtenso(722), 'setecentos e vinte e dois')
  assert.equal(porExtenso(723), 'setecentos e vinte e três')
  assert.equal(porExtenso(724), 'setecentos e vinte e quatro')
  assert.equal(porExtenso(725), 'setecentos e vinte e cinco')
  assert.equal(porExtenso(726), 'setecentos e vinte e seis')
  assert.equal(porExtenso(727), 'setecentos e vinte e sete')
  assert.equal(porExtenso(728), 'setecentos e vinte e oito')
  assert.equal(porExtenso(729), 'setecentos e vinte e nove')

  assert.equal(porExtenso(730), 'setecentos e trinta')
  assert.equal(porExtenso(731), 'setecentos e trinta e um')
  assert.equal(porExtenso(732), 'setecentos e trinta e dois')
  assert.equal(porExtenso(733), 'setecentos e trinta e três')
  assert.equal(porExtenso(734), 'setecentos e trinta e quatro')
  assert.equal(porExtenso(735), 'setecentos e trinta e cinco')
  assert.equal(porExtenso(736), 'setecentos e trinta e seis')
  assert.equal(porExtenso(737), 'setecentos e trinta e sete')
  assert.equal(porExtenso(738), 'setecentos e trinta e oito')
  assert.equal(porExtenso(739), 'setecentos e trinta e nove')

  assert.equal(porExtenso(740), 'setecentos e quarenta')
  assert.equal(porExtenso(741), 'setecentos e quarenta e um')
  assert.equal(porExtenso(742), 'setecentos e quarenta e dois')
  assert.equal(porExtenso(743), 'setecentos e quarenta e três')
  assert.equal(porExtenso(744), 'setecentos e quarenta e quatro')
  assert.equal(porExtenso(745), 'setecentos e quarenta e cinco')
  assert.equal(porExtenso(746), 'setecentos e quarenta e seis')
  assert.equal(porExtenso(747), 'setecentos e quarenta e sete')
  assert.equal(porExtenso(748), 'setecentos e quarenta e oito')
  assert.equal(porExtenso(749), 'setecentos e quarenta e nove')

  assert.equal(porExtenso(750), 'setecentos e cinquenta')
  assert.equal(porExtenso(751), 'setecentos e cinquenta e um')
  assert.equal(porExtenso(752), 'setecentos e cinquenta e dois')
  assert.equal(porExtenso(753), 'setecentos e cinquenta e três')
  assert.equal(porExtenso(754), 'setecentos e cinquenta e quatro')
  assert.equal(porExtenso(755), 'setecentos e cinquenta e cinco')
  assert.equal(porExtenso(756), 'setecentos e cinquenta e seis')
  assert.equal(porExtenso(757), 'setecentos e cinquenta e sete')
  assert.equal(porExtenso(758), 'setecentos e cinquenta e oito')
  assert.equal(porExtenso(759), 'setecentos e cinquenta e nove')

  assert.equal(porExtenso(760), 'setecentos e sessenta')
  assert.equal(porExtenso(761), 'setecentos e sessenta e um')
  assert.equal(porExtenso(762), 'setecentos e sessenta e dois')
  assert.equal(porExtenso(763), 'setecentos e sessenta e três')
  assert.equal(porExtenso(764), 'setecentos e sessenta e quatro')
  assert.equal(porExtenso(765), 'setecentos e sessenta e cinco')
  assert.equal(porExtenso(766), 'setecentos e sessenta e seis')
  assert.equal(porExtenso(767), 'setecentos e sessenta e sete')
  assert.equal(porExtenso(768), 'setecentos e sessenta e oito')
  assert.equal(porExtenso(769), 'setecentos e sessenta e nove')

  assert.equal(porExtenso(770), 'setecentos e setenta')
  assert.equal(porExtenso(771), 'setecentos e setenta e um')
  assert.equal(porExtenso(772), 'setecentos e setenta e dois')
  assert.equal(porExtenso(773), 'setecentos e setenta e três')
  assert.equal(porExtenso(774), 'setecentos e setenta e quatro')
  assert.equal(porExtenso(775), 'setecentos e setenta e cinco')
  assert.equal(porExtenso(776), 'setecentos e setenta e seis')
  assert.equal(porExtenso(777), 'setecentos e setenta e sete')
  assert.equal(porExtenso(778), 'setecentos e setenta e oito')
  assert.equal(porExtenso(779), 'setecentos e setenta e nove')

  assert.equal(porExtenso(780), 'setecentos e oitenta')
  assert.equal(porExtenso(781), 'setecentos e oitenta e um')
  assert.equal(porExtenso(782), 'setecentos e oitenta e dois')
  assert.equal(porExtenso(783), 'setecentos e oitenta e três')
  assert.equal(porExtenso(784), 'setecentos e oitenta e quatro')
  assert.equal(porExtenso(785), 'setecentos e oitenta e cinco')
  assert.equal(porExtenso(786), 'setecentos e oitenta e seis')
  assert.equal(porExtenso(787), 'setecentos e oitenta e sete')
  assert.equal(porExtenso(788), 'setecentos e oitenta e oito')
  assert.equal(porExtenso(789), 'setecentos e oitenta e nove')

  assert.equal(porExtenso(790), 'setecentos e noventa')
  assert.equal(porExtenso(791), 'setecentos e noventa e um')
  assert.equal(porExtenso(792), 'setecentos e noventa e dois')
  assert.equal(porExtenso(793), 'setecentos e noventa e três')
  assert.equal(porExtenso(794), 'setecentos e noventa e quatro')
  assert.equal(porExtenso(795), 'setecentos e noventa e cinco')
  assert.equal(porExtenso(796), 'setecentos e noventa e seis')
  assert.equal(porExtenso(797), 'setecentos e noventa e sete')
  assert.equal(porExtenso(798), 'setecentos e noventa e oito')
  assert.equal(porExtenso(799), 'setecentos e noventa e nove')
})

it('setecentos+', () => {
  assert.equal(porExtenso.parse('setecentos'), '700')
  assert.equal(porExtenso.parse('setecentos e um'), '701')
  assert.equal(porExtenso.parse('setecentos e dois'), '702')
  assert.equal(porExtenso.parse('setecentos e três'), '703')
  assert.equal(porExtenso.parse('setecentos e quatro'), '704')
  assert.equal(porExtenso.parse('setecentos e cinco'), '705')
  assert.equal(porExtenso.parse('setecentos e seis'), '706')
  assert.equal(porExtenso.parse('setecentos e sete'), '707')
  assert.equal(porExtenso.parse('setecentos e oito'), '708')
  assert.equal(porExtenso.parse('setecentos e nove'), '709')

  assert.equal(porExtenso.parse('setecentos e dez'), '710')
  assert.equal(porExtenso.parse('setecentos e onze'), '711')
  assert.equal(porExtenso.parse('setecentos e doze'), '712')
  assert.equal(porExtenso.parse('setecentos e treze'), '713')
  assert.equal(porExtenso.parse('setecentos e quatorze'), '714')
  assert.equal(porExtenso.parse('setecentos e quinze'), '715')
  assert.equal(porExtenso.parse('setecentos e dezesseis'), '716')
  assert.equal(porExtenso.parse('setecentos e dezessete'), '717')
  assert.equal(porExtenso.parse('setecentos e dezoito'), '718')
  assert.equal(porExtenso.parse('setecentos e dezenove'), '719')

  assert.equal(porExtenso.parse('setecentos e vinte'), '720')
  assert.equal(porExtenso.parse('setecentos e vinte e um'), '721')
  assert.equal(porExtenso.parse('setecentos e vinte e dois'), '722')
  assert.equal(porExtenso.parse('setecentos e vinte e três'), '723')
  assert.equal(porExtenso.parse('setecentos e vinte e quatro'), '724')
  assert.equal(porExtenso.parse('setecentos e vinte e cinco'), '725')
  assert.equal(porExtenso.parse('setecentos e vinte e seis'), '726')
  assert.equal(porExtenso.parse('setecentos e vinte e sete'), '727')
  assert.equal(porExtenso.parse('setecentos e vinte e oito'), '728')
  assert.equal(porExtenso.parse('setecentos e vinte e nove'), '729')

  assert.equal(porExtenso.parse('setecentos e trinta'), '730')
  assert.equal(porExtenso.parse('setecentos e trinta e um'), '731')
  assert.equal(porExtenso.parse('setecentos e trinta e dois'), '732')
  assert.equal(porExtenso.parse('setecentos e trinta e três'), '733')
  assert.equal(porExtenso.parse('setecentos e trinta e quatro'), '734')
  assert.equal(porExtenso.parse('setecentos e trinta e cinco'), '735')
  assert.equal(porExtenso.parse('setecentos e trinta e seis'), '736')
  assert.equal(porExtenso.parse('setecentos e trinta e sete'), '737')
  assert.equal(porExtenso.parse('setecentos e trinta e oito'), '738')
  assert.equal(porExtenso.parse('setecentos e trinta e nove'), '739')

  assert.equal(porExtenso.parse('setecentos e quarenta'), '740')
  assert.equal(porExtenso.parse('setecentos e quarenta e um'), '741')
  assert.equal(porExtenso.parse('setecentos e quarenta e dois'), '742')
  assert.equal(porExtenso.parse('setecentos e quarenta e três'), '743')
  assert.equal(porExtenso.parse('setecentos e quarenta e quatro'), '744')
  assert.equal(porExtenso.parse('setecentos e quarenta e cinco'), '745')
  assert.equal(porExtenso.parse('setecentos e quarenta e seis'), '746')
  assert.equal(porExtenso.parse('setecentos e quarenta e sete'), '747')
  assert.equal(porExtenso.parse('setecentos e quarenta e oito'), '748')
  assert.equal(porExtenso.parse('setecentos e quarenta e nove'), '749')

  assert.equal(porExtenso.parse('setecentos e cinquenta'), '750')
  assert.equal(porExtenso.parse('setecentos e cinquenta e um'), '751')
  assert.equal(porExtenso.parse('setecentos e cinquenta e dois'), '752')
  assert.equal(porExtenso.parse('setecentos e cinquenta e três'), '753')
  assert.equal(porExtenso.parse('setecentos e cinquenta e quatro'), '754')
  assert.equal(porExtenso.parse('setecentos e cinquenta e cinco'), '755')
  assert.equal(porExtenso.parse('setecentos e cinquenta e seis'), '756')
  assert.equal(porExtenso.parse('setecentos e cinquenta e sete'), '757')
  assert.equal(porExtenso.parse('setecentos e cinquenta e oito'), '758')
  assert.equal(porExtenso.parse('setecentos e cinquenta e nove'), '759')

  assert.equal(porExtenso.parse('setecentos e sessenta'), '760')
  assert.equal(porExtenso.parse('setecentos e sessenta e um'), '761')
  assert.equal(porExtenso.parse('setecentos e sessenta e dois'), '762')
  assert.equal(porExtenso.parse('setecentos e sessenta e três'), '763')
  assert.equal(porExtenso.parse('setecentos e sessenta e quatro'), '764')
  assert.equal(porExtenso.parse('setecentos e sessenta e cinco'), '765')
  assert.equal(porExtenso.parse('setecentos e sessenta e seis'), '766')
  assert.equal(porExtenso.parse('setecentos e sessenta e sete'), '767')
  assert.equal(porExtenso.parse('setecentos e sessenta e oito'), '768')
  assert.equal(porExtenso.parse('setecentos e sessenta e nove'), '769')

  assert.equal(porExtenso.parse('setecentos e setenta'), '770')
  assert.equal(porExtenso.parse('setecentos e setenta e um'), '771')
  assert.equal(porExtenso.parse('setecentos e setenta e dois'), '772')
  assert.equal(porExtenso.parse('setecentos e setenta e três'), '773')
  assert.equal(porExtenso.parse('setecentos e setenta e quatro'), '774')
  assert.equal(porExtenso.parse('setecentos e setenta e cinco'), '775')
  assert.equal(porExtenso.parse('setecentos e setenta e seis'), '776')
  assert.equal(porExtenso.parse('setecentos e setenta e sete'), '777')
  assert.equal(porExtenso.parse('setecentos e setenta e oito'), '778')
  assert.equal(porExtenso.parse('setecentos e setenta e nove'), '779')

  assert.equal(porExtenso.parse('setecentos e oitenta'), '780')
  assert.equal(porExtenso.parse('setecentos e oitenta e um'), '781')
  assert.equal(porExtenso.parse('setecentos e oitenta e dois'), '782')
  assert.equal(porExtenso.parse('setecentos e oitenta e três'), '783')
  assert.equal(porExtenso.parse('setecentos e oitenta e quatro'), '784')
  assert.equal(porExtenso.parse('setecentos e oitenta e cinco'), '785')
  assert.equal(porExtenso.parse('setecentos e oitenta e seis'), '786')
  assert.equal(porExtenso.parse('setecentos e oitenta e sete'), '787')
  assert.equal(porExtenso.parse('setecentos e oitenta e oito'), '788')
  assert.equal(porExtenso.parse('setecentos e oitenta e nove'), '789')

  assert.equal(porExtenso.parse('setecentos e noventa'), '790')
  assert.equal(porExtenso.parse('setecentos e noventa e um'), '791')
  assert.equal(porExtenso.parse('setecentos e noventa e dois'), '792')
  assert.equal(porExtenso.parse('setecentos e noventa e três'), '793')
  assert.equal(porExtenso.parse('setecentos e noventa e quatro'), '794')
  assert.equal(porExtenso.parse('setecentos e noventa e cinco'), '795')
  assert.equal(porExtenso.parse('setecentos e noventa e seis'), '796')
  assert.equal(porExtenso.parse('setecentos e noventa e sete'), '797')
  assert.equal(porExtenso.parse('setecentos e noventa e oito'), '798')
  assert.equal(porExtenso.parse('setecentos e noventa e nove'), '799')
})

it('800+', () => {
  assert.equal(porExtenso(800), 'oitocentos')
  assert.equal(porExtenso(801), 'oitocentos e um')
  assert.equal(porExtenso(802), 'oitocentos e dois')
  assert.equal(porExtenso(803), 'oitocentos e três')
  assert.equal(porExtenso(804), 'oitocentos e quatro')
  assert.equal(porExtenso(805), 'oitocentos e cinco')
  assert.equal(porExtenso(806), 'oitocentos e seis')
  assert.equal(porExtenso(807), 'oitocentos e sete')
  assert.equal(porExtenso(808), 'oitocentos e oito')
  assert.equal(porExtenso(809), 'oitocentos e nove')

  assert.equal(porExtenso(810), 'oitocentos e dez')
  assert.equal(porExtenso(811), 'oitocentos e onze')
  assert.equal(porExtenso(812), 'oitocentos e doze')
  assert.equal(porExtenso(813), 'oitocentos e treze')
  assert.equal(porExtenso(814), 'oitocentos e quatorze')
  assert.equal(porExtenso(815), 'oitocentos e quinze')
  assert.equal(porExtenso(816), 'oitocentos e dezesseis')
  assert.equal(porExtenso(817), 'oitocentos e dezessete')
  assert.equal(porExtenso(818), 'oitocentos e dezoito')
  assert.equal(porExtenso(819), 'oitocentos e dezenove')

  assert.equal(porExtenso(820), 'oitocentos e vinte')
  assert.equal(porExtenso(821), 'oitocentos e vinte e um')
  assert.equal(porExtenso(822), 'oitocentos e vinte e dois')
  assert.equal(porExtenso(823), 'oitocentos e vinte e três')
  assert.equal(porExtenso(824), 'oitocentos e vinte e quatro')
  assert.equal(porExtenso(825), 'oitocentos e vinte e cinco')
  assert.equal(porExtenso(826), 'oitocentos e vinte e seis')
  assert.equal(porExtenso(827), 'oitocentos e vinte e sete')
  assert.equal(porExtenso(828), 'oitocentos e vinte e oito')
  assert.equal(porExtenso(829), 'oitocentos e vinte e nove')

  assert.equal(porExtenso(830), 'oitocentos e trinta')
  assert.equal(porExtenso(831), 'oitocentos e trinta e um')
  assert.equal(porExtenso(832), 'oitocentos e trinta e dois')
  assert.equal(porExtenso(833), 'oitocentos e trinta e três')
  assert.equal(porExtenso(834), 'oitocentos e trinta e quatro')
  assert.equal(porExtenso(835), 'oitocentos e trinta e cinco')
  assert.equal(porExtenso(836), 'oitocentos e trinta e seis')
  assert.equal(porExtenso(837), 'oitocentos e trinta e sete')
  assert.equal(porExtenso(838), 'oitocentos e trinta e oito')
  assert.equal(porExtenso(839), 'oitocentos e trinta e nove')

  assert.equal(porExtenso(840), 'oitocentos e quarenta')
  assert.equal(porExtenso(841), 'oitocentos e quarenta e um')
  assert.equal(porExtenso(842), 'oitocentos e quarenta e dois')
  assert.equal(porExtenso(843), 'oitocentos e quarenta e três')
  assert.equal(porExtenso(844), 'oitocentos e quarenta e quatro')
  assert.equal(porExtenso(845), 'oitocentos e quarenta e cinco')
  assert.equal(porExtenso(846), 'oitocentos e quarenta e seis')
  assert.equal(porExtenso(847), 'oitocentos e quarenta e sete')
  assert.equal(porExtenso(848), 'oitocentos e quarenta e oito')
  assert.equal(porExtenso(849), 'oitocentos e quarenta e nove')

  assert.equal(porExtenso(850), 'oitocentos e cinquenta')
  assert.equal(porExtenso(851), 'oitocentos e cinquenta e um')
  assert.equal(porExtenso(852), 'oitocentos e cinquenta e dois')
  assert.equal(porExtenso(853), 'oitocentos e cinquenta e três')
  assert.equal(porExtenso(854), 'oitocentos e cinquenta e quatro')
  assert.equal(porExtenso(855), 'oitocentos e cinquenta e cinco')
  assert.equal(porExtenso(856), 'oitocentos e cinquenta e seis')
  assert.equal(porExtenso(857), 'oitocentos e cinquenta e sete')
  assert.equal(porExtenso(858), 'oitocentos e cinquenta e oito')
  assert.equal(porExtenso(859), 'oitocentos e cinquenta e nove')

  assert.equal(porExtenso(860), 'oitocentos e sessenta')
  assert.equal(porExtenso(861), 'oitocentos e sessenta e um')
  assert.equal(porExtenso(862), 'oitocentos e sessenta e dois')
  assert.equal(porExtenso(863), 'oitocentos e sessenta e três')
  assert.equal(porExtenso(864), 'oitocentos e sessenta e quatro')
  assert.equal(porExtenso(865), 'oitocentos e sessenta e cinco')
  assert.equal(porExtenso(866), 'oitocentos e sessenta e seis')
  assert.equal(porExtenso(867), 'oitocentos e sessenta e sete')
  assert.equal(porExtenso(868), 'oitocentos e sessenta e oito')
  assert.equal(porExtenso(869), 'oitocentos e sessenta e nove')

  assert.equal(porExtenso(870), 'oitocentos e setenta')
  assert.equal(porExtenso(871), 'oitocentos e setenta e um')
  assert.equal(porExtenso(872), 'oitocentos e setenta e dois')
  assert.equal(porExtenso(873), 'oitocentos e setenta e três')
  assert.equal(porExtenso(874), 'oitocentos e setenta e quatro')
  assert.equal(porExtenso(875), 'oitocentos e setenta e cinco')
  assert.equal(porExtenso(876), 'oitocentos e setenta e seis')
  assert.equal(porExtenso(877), 'oitocentos e setenta e sete')
  assert.equal(porExtenso(878), 'oitocentos e setenta e oito')
  assert.equal(porExtenso(879), 'oitocentos e setenta e nove')

  assert.equal(porExtenso(880), 'oitocentos e oitenta')
  assert.equal(porExtenso(881), 'oitocentos e oitenta e um')
  assert.equal(porExtenso(882), 'oitocentos e oitenta e dois')
  assert.equal(porExtenso(883), 'oitocentos e oitenta e três')
  assert.equal(porExtenso(884), 'oitocentos e oitenta e quatro')
  assert.equal(porExtenso(885), 'oitocentos e oitenta e cinco')
  assert.equal(porExtenso(886), 'oitocentos e oitenta e seis')
  assert.equal(porExtenso(887), 'oitocentos e oitenta e sete')
  assert.equal(porExtenso(888), 'oitocentos e oitenta e oito')
  assert.equal(porExtenso(889), 'oitocentos e oitenta e nove')

  assert.equal(porExtenso(890), 'oitocentos e noventa')
  assert.equal(porExtenso(891), 'oitocentos e noventa e um')
  assert.equal(porExtenso(892), 'oitocentos e noventa e dois')
  assert.equal(porExtenso(893), 'oitocentos e noventa e três')
  assert.equal(porExtenso(894), 'oitocentos e noventa e quatro')
  assert.equal(porExtenso(895), 'oitocentos e noventa e cinco')
  assert.equal(porExtenso(896), 'oitocentos e noventa e seis')
  assert.equal(porExtenso(897), 'oitocentos e noventa e sete')
  assert.equal(porExtenso(898), 'oitocentos e noventa e oito')
  assert.equal(porExtenso(899), 'oitocentos e noventa e nove')
})

it('oitocentos+', () => {
  assert.equal(porExtenso.parse('oitocentos'), '800')
  assert.equal(porExtenso.parse('oitocentos e um'), '801')
  assert.equal(porExtenso.parse('oitocentos e dois'), '802')
  assert.equal(porExtenso.parse('oitocentos e três'), '803')
  assert.equal(porExtenso.parse('oitocentos e quatro'), '804')
  assert.equal(porExtenso.parse('oitocentos e cinco'), '805')
  assert.equal(porExtenso.parse('oitocentos e seis'), '806')
  assert.equal(porExtenso.parse('oitocentos e sete'), '807')
  assert.equal(porExtenso.parse('oitocentos e oito'), '808')
  assert.equal(porExtenso.parse('oitocentos e nove'), '809')

  assert.equal(porExtenso.parse('oitocentos e dez'), '810')
  assert.equal(porExtenso.parse('oitocentos e onze'), '811')
  assert.equal(porExtenso.parse('oitocentos e doze'), '812')
  assert.equal(porExtenso.parse('oitocentos e treze'), '813')
  assert.equal(porExtenso.parse('oitocentos e quatorze'), '814')
  assert.equal(porExtenso.parse('oitocentos e quinze'), '815')
  assert.equal(porExtenso.parse('oitocentos e dezesseis'), '816')
  assert.equal(porExtenso.parse('oitocentos e dezessete'), '817')
  assert.equal(porExtenso.parse('oitocentos e dezoito'), '818')
  assert.equal(porExtenso.parse('oitocentos e dezenove'), '819')

  assert.equal(porExtenso.parse('oitocentos e vinte'), '820')
  assert.equal(porExtenso.parse('oitocentos e vinte e um'), '821')
  assert.equal(porExtenso.parse('oitocentos e vinte e dois'), '822')
  assert.equal(porExtenso.parse('oitocentos e vinte e três'), '823')
  assert.equal(porExtenso.parse('oitocentos e vinte e quatro'), '824')
  assert.equal(porExtenso.parse('oitocentos e vinte e cinco'), '825')
  assert.equal(porExtenso.parse('oitocentos e vinte e seis'), '826')
  assert.equal(porExtenso.parse('oitocentos e vinte e sete'), '827')
  assert.equal(porExtenso.parse('oitocentos e vinte e oito'), '828')
  assert.equal(porExtenso.parse('oitocentos e vinte e nove'), '829')

  assert.equal(porExtenso.parse('oitocentos e trinta'), '830')
  assert.equal(porExtenso.parse('oitocentos e trinta e um'), '831')
  assert.equal(porExtenso.parse('oitocentos e trinta e dois'), '832')
  assert.equal(porExtenso.parse('oitocentos e trinta e três'), '833')
  assert.equal(porExtenso.parse('oitocentos e trinta e quatro'), '834')
  assert.equal(porExtenso.parse('oitocentos e trinta e cinco'), '835')
  assert.equal(porExtenso.parse('oitocentos e trinta e seis'), '836')
  assert.equal(porExtenso.parse('oitocentos e trinta e sete'), '837')
  assert.equal(porExtenso.parse('oitocentos e trinta e oito'), '838')
  assert.equal(porExtenso.parse('oitocentos e trinta e nove'), '839')

  assert.equal(porExtenso.parse('oitocentos e quarenta'), '840')
  assert.equal(porExtenso.parse('oitocentos e quarenta e um'), '841')
  assert.equal(porExtenso.parse('oitocentos e quarenta e dois'), '842')
  assert.equal(porExtenso.parse('oitocentos e quarenta e três'), '843')
  assert.equal(porExtenso.parse('oitocentos e quarenta e quatro'), '844')
  assert.equal(porExtenso.parse('oitocentos e quarenta e cinco'), '845')
  assert.equal(porExtenso.parse('oitocentos e quarenta e seis'), '846')
  assert.equal(porExtenso.parse('oitocentos e quarenta e sete'), '847')
  assert.equal(porExtenso.parse('oitocentos e quarenta e oito'), '848')
  assert.equal(porExtenso.parse('oitocentos e quarenta e nove'), '849')

  assert.equal(porExtenso.parse('oitocentos e cinquenta'), '850')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e um'), '851')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e dois'), '852')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e três'), '853')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e quatro'), '854')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e cinco'), '855')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e seis'), '856')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e sete'), '857')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e oito'), '858')
  assert.equal(porExtenso.parse('oitocentos e cinquenta e nove'), '859')

  assert.equal(porExtenso.parse('oitocentos e sessenta'), '860')
  assert.equal(porExtenso.parse('oitocentos e sessenta e um'), '861')
  assert.equal(porExtenso.parse('oitocentos e sessenta e dois'), '862')
  assert.equal(porExtenso.parse('oitocentos e sessenta e três'), '863')
  assert.equal(porExtenso.parse('oitocentos e sessenta e quatro'), '864')
  assert.equal(porExtenso.parse('oitocentos e sessenta e cinco'), '865')
  assert.equal(porExtenso.parse('oitocentos e sessenta e seis'), '866')
  assert.equal(porExtenso.parse('oitocentos e sessenta e sete'), '867')
  assert.equal(porExtenso.parse('oitocentos e sessenta e oito'), '868')
  assert.equal(porExtenso.parse('oitocentos e sessenta e nove'), '869')

  assert.equal(porExtenso.parse('oitocentos e setenta'), '870')
  assert.equal(porExtenso.parse('oitocentos e setenta e um'), '871')
  assert.equal(porExtenso.parse('oitocentos e setenta e dois'), '872')
  assert.equal(porExtenso.parse('oitocentos e setenta e três'), '873')
  assert.equal(porExtenso.parse('oitocentos e setenta e quatro'), '874')
  assert.equal(porExtenso.parse('oitocentos e setenta e cinco'), '875')
  assert.equal(porExtenso.parse('oitocentos e setenta e seis'), '876')
  assert.equal(porExtenso.parse('oitocentos e setenta e sete'), '877')
  assert.equal(porExtenso.parse('oitocentos e setenta e oito'), '878')
  assert.equal(porExtenso.parse('oitocentos e setenta e nove'), '879')

  assert.equal(porExtenso.parse('oitocentos e oitenta'), '880')
  assert.equal(porExtenso.parse('oitocentos e oitenta e um'), '881')
  assert.equal(porExtenso.parse('oitocentos e oitenta e dois'), '882')
  assert.equal(porExtenso.parse('oitocentos e oitenta e três'), '883')
  assert.equal(porExtenso.parse('oitocentos e oitenta e quatro'), '884')
  assert.equal(porExtenso.parse('oitocentos e oitenta e cinco'), '885')
  assert.equal(porExtenso.parse('oitocentos e oitenta e seis'), '886')
  assert.equal(porExtenso.parse('oitocentos e oitenta e sete'), '887')
  assert.equal(porExtenso.parse('oitocentos e oitenta e oito'), '888')
  assert.equal(porExtenso.parse('oitocentos e oitenta e nove'), '889')

  assert.equal(porExtenso.parse('oitocentos e noventa'), '890')
  assert.equal(porExtenso.parse('oitocentos e noventa e um'), '891')
  assert.equal(porExtenso.parse('oitocentos e noventa e dois'), '892')
  assert.equal(porExtenso.parse('oitocentos e noventa e três'), '893')
  assert.equal(porExtenso.parse('oitocentos e noventa e quatro'), '894')
  assert.equal(porExtenso.parse('oitocentos e noventa e cinco'), '895')
  assert.equal(porExtenso.parse('oitocentos e noventa e seis'), '896')
  assert.equal(porExtenso.parse('oitocentos e noventa e sete'), '897')
  assert.equal(porExtenso.parse('oitocentos e noventa e oito'), '898')
  assert.equal(porExtenso.parse('oitocentos e noventa e nove'), '899')
})

it('900+', () => {
  assert.equal(porExtenso(900), 'novecentos')
  assert.equal(porExtenso(901), 'novecentos e um')
  assert.equal(porExtenso(902), 'novecentos e dois')
  assert.equal(porExtenso(903), 'novecentos e três')
  assert.equal(porExtenso(904), 'novecentos e quatro')
  assert.equal(porExtenso(905), 'novecentos e cinco')
  assert.equal(porExtenso(906), 'novecentos e seis')
  assert.equal(porExtenso(907), 'novecentos e sete')
  assert.equal(porExtenso(908), 'novecentos e oito')
  assert.equal(porExtenso(909), 'novecentos e nove')

  assert.equal(porExtenso(910), 'novecentos e dez')
  assert.equal(porExtenso(911), 'novecentos e onze')
  assert.equal(porExtenso(912), 'novecentos e doze')
  assert.equal(porExtenso(913), 'novecentos e treze')
  assert.equal(porExtenso(914), 'novecentos e quatorze')
  assert.equal(porExtenso(915), 'novecentos e quinze')
  assert.equal(porExtenso(916), 'novecentos e dezesseis')
  assert.equal(porExtenso(917), 'novecentos e dezessete')
  assert.equal(porExtenso(918), 'novecentos e dezoito')
  assert.equal(porExtenso(919), 'novecentos e dezenove')

  assert.equal(porExtenso(920), 'novecentos e vinte')
  assert.equal(porExtenso(921), 'novecentos e vinte e um')
  assert.equal(porExtenso(922), 'novecentos e vinte e dois')
  assert.equal(porExtenso(923), 'novecentos e vinte e três')
  assert.equal(porExtenso(924), 'novecentos e vinte e quatro')
  assert.equal(porExtenso(925), 'novecentos e vinte e cinco')
  assert.equal(porExtenso(926), 'novecentos e vinte e seis')
  assert.equal(porExtenso(927), 'novecentos e vinte e sete')
  assert.equal(porExtenso(928), 'novecentos e vinte e oito')
  assert.equal(porExtenso(929), 'novecentos e vinte e nove')

  assert.equal(porExtenso(930), 'novecentos e trinta')
  assert.equal(porExtenso(931), 'novecentos e trinta e um')
  assert.equal(porExtenso(932), 'novecentos e trinta e dois')
  assert.equal(porExtenso(933), 'novecentos e trinta e três')
  assert.equal(porExtenso(934), 'novecentos e trinta e quatro')
  assert.equal(porExtenso(935), 'novecentos e trinta e cinco')
  assert.equal(porExtenso(936), 'novecentos e trinta e seis')
  assert.equal(porExtenso(937), 'novecentos e trinta e sete')
  assert.equal(porExtenso(938), 'novecentos e trinta e oito')
  assert.equal(porExtenso(939), 'novecentos e trinta e nove')

  assert.equal(porExtenso(940), 'novecentos e quarenta')
  assert.equal(porExtenso(941), 'novecentos e quarenta e um')
  assert.equal(porExtenso(942), 'novecentos e quarenta e dois')
  assert.equal(porExtenso(943), 'novecentos e quarenta e três')
  assert.equal(porExtenso(944), 'novecentos e quarenta e quatro')
  assert.equal(porExtenso(945), 'novecentos e quarenta e cinco')
  assert.equal(porExtenso(946), 'novecentos e quarenta e seis')
  assert.equal(porExtenso(947), 'novecentos e quarenta e sete')
  assert.equal(porExtenso(948), 'novecentos e quarenta e oito')
  assert.equal(porExtenso(949), 'novecentos e quarenta e nove')

  assert.equal(porExtenso(950), 'novecentos e cinquenta')
  assert.equal(porExtenso(951), 'novecentos e cinquenta e um')
  assert.equal(porExtenso(952), 'novecentos e cinquenta e dois')
  assert.equal(porExtenso(953), 'novecentos e cinquenta e três')
  assert.equal(porExtenso(954), 'novecentos e cinquenta e quatro')
  assert.equal(porExtenso(955), 'novecentos e cinquenta e cinco')
  assert.equal(porExtenso(956), 'novecentos e cinquenta e seis')
  assert.equal(porExtenso(957), 'novecentos e cinquenta e sete')
  assert.equal(porExtenso(958), 'novecentos e cinquenta e oito')
  assert.equal(porExtenso(959), 'novecentos e cinquenta e nove')

  assert.equal(porExtenso(960), 'novecentos e sessenta')
  assert.equal(porExtenso(961), 'novecentos e sessenta e um')
  assert.equal(porExtenso(962), 'novecentos e sessenta e dois')
  assert.equal(porExtenso(963), 'novecentos e sessenta e três')
  assert.equal(porExtenso(964), 'novecentos e sessenta e quatro')
  assert.equal(porExtenso(965), 'novecentos e sessenta e cinco')
  assert.equal(porExtenso(966), 'novecentos e sessenta e seis')
  assert.equal(porExtenso(967), 'novecentos e sessenta e sete')
  assert.equal(porExtenso(968), 'novecentos e sessenta e oito')
  assert.equal(porExtenso(969), 'novecentos e sessenta e nove')

  assert.equal(porExtenso(970), 'novecentos e setenta')
  assert.equal(porExtenso(971), 'novecentos e setenta e um')
  assert.equal(porExtenso(972), 'novecentos e setenta e dois')
  assert.equal(porExtenso(973), 'novecentos e setenta e três')
  assert.equal(porExtenso(974), 'novecentos e setenta e quatro')
  assert.equal(porExtenso(975), 'novecentos e setenta e cinco')
  assert.equal(porExtenso(976), 'novecentos e setenta e seis')
  assert.equal(porExtenso(977), 'novecentos e setenta e sete')
  assert.equal(porExtenso(978), 'novecentos e setenta e oito')
  assert.equal(porExtenso(979), 'novecentos e setenta e nove')

  assert.equal(porExtenso(980), 'novecentos e oitenta')
  assert.equal(porExtenso(981), 'novecentos e oitenta e um')
  assert.equal(porExtenso(982), 'novecentos e oitenta e dois')
  assert.equal(porExtenso(983), 'novecentos e oitenta e três')
  assert.equal(porExtenso(984), 'novecentos e oitenta e quatro')
  assert.equal(porExtenso(985), 'novecentos e oitenta e cinco')
  assert.equal(porExtenso(986), 'novecentos e oitenta e seis')
  assert.equal(porExtenso(987), 'novecentos e oitenta e sete')
  assert.equal(porExtenso(988), 'novecentos e oitenta e oito')
  assert.equal(porExtenso(989), 'novecentos e oitenta e nove')

  assert.equal(porExtenso(990), 'novecentos e noventa')
  assert.equal(porExtenso(991), 'novecentos e noventa e um')
  assert.equal(porExtenso(992), 'novecentos e noventa e dois')
  assert.equal(porExtenso(993), 'novecentos e noventa e três')
  assert.equal(porExtenso(994), 'novecentos e noventa e quatro')
  assert.equal(porExtenso(995), 'novecentos e noventa e cinco')
  assert.equal(porExtenso(996), 'novecentos e noventa e seis')
  assert.equal(porExtenso(997), 'novecentos e noventa e sete')
  assert.equal(porExtenso(998), 'novecentos e noventa e oito')
  assert.equal(porExtenso(999), 'novecentos e noventa e nove')
})

it('novecentos+', () => {
  assert.equal(porExtenso.parse('novecentos'), '900')
  assert.equal(porExtenso.parse('novecentos e um'), '901')
  assert.equal(porExtenso.parse('novecentos e dois'), '902')
  assert.equal(porExtenso.parse('novecentos e três'), '903')
  assert.equal(porExtenso.parse('novecentos e quatro'), '904')
  assert.equal(porExtenso.parse('novecentos e cinco'), '905')
  assert.equal(porExtenso.parse('novecentos e seis'), '906')
  assert.equal(porExtenso.parse('novecentos e sete'), '907')
  assert.equal(porExtenso.parse('novecentos e oito'), '908')
  assert.equal(porExtenso.parse('novecentos e nove'), '909')

  assert.equal(porExtenso.parse('novecentos e dez'), '910')
  assert.equal(porExtenso.parse('novecentos e onze'), '911')
  assert.equal(porExtenso.parse('novecentos e doze'), '912')
  assert.equal(porExtenso.parse('novecentos e treze'), '913')
  assert.equal(porExtenso.parse('novecentos e quatorze'), '914')
  assert.equal(porExtenso.parse('novecentos e quinze'), '915')
  assert.equal(porExtenso.parse('novecentos e dezesseis'), '916')
  assert.equal(porExtenso.parse('novecentos e dezessete'), '917')
  assert.equal(porExtenso.parse('novecentos e dezoito'), '918')
  assert.equal(porExtenso.parse('novecentos e dezenove'), '919')

  assert.equal(porExtenso.parse('novecentos e vinte'), '920')
  assert.equal(porExtenso.parse('novecentos e vinte e um'), '921')
  assert.equal(porExtenso.parse('novecentos e vinte e dois'), '922')
  assert.equal(porExtenso.parse('novecentos e vinte e três'), '923')
  assert.equal(porExtenso.parse('novecentos e vinte e quatro'), '924')
  assert.equal(porExtenso.parse('novecentos e vinte e cinco'), '925')
  assert.equal(porExtenso.parse('novecentos e vinte e seis'), '926')
  assert.equal(porExtenso.parse('novecentos e vinte e sete'), '927')
  assert.equal(porExtenso.parse('novecentos e vinte e oito'), '928')
  assert.equal(porExtenso.parse('novecentos e vinte e nove'), '929')

  assert.equal(porExtenso.parse('novecentos e trinta'), '930')
  assert.equal(porExtenso.parse('novecentos e trinta e um'), '931')
  assert.equal(porExtenso.parse('novecentos e trinta e dois'), '932')
  assert.equal(porExtenso.parse('novecentos e trinta e três'), '933')
  assert.equal(porExtenso.parse('novecentos e trinta e quatro'), '934')
  assert.equal(porExtenso.parse('novecentos e trinta e cinco'), '935')
  assert.equal(porExtenso.parse('novecentos e trinta e seis'), '936')
  assert.equal(porExtenso.parse('novecentos e trinta e sete'), '937')
  assert.equal(porExtenso.parse('novecentos e trinta e oito'), '938')
  assert.equal(porExtenso.parse('novecentos e trinta e nove'), '939')

  assert.equal(porExtenso.parse('novecentos e quarenta'), '940')
  assert.equal(porExtenso.parse('novecentos e quarenta e um'), '941')
  assert.equal(porExtenso.parse('novecentos e quarenta e dois'), '942')
  assert.equal(porExtenso.parse('novecentos e quarenta e três'), '943')
  assert.equal(porExtenso.parse('novecentos e quarenta e quatro'), '944')
  assert.equal(porExtenso.parse('novecentos e quarenta e cinco'), '945')
  assert.equal(porExtenso.parse('novecentos e quarenta e seis'), '946')
  assert.equal(porExtenso.parse('novecentos e quarenta e sete'), '947')
  assert.equal(porExtenso.parse('novecentos e quarenta e oito'), '948')
  assert.equal(porExtenso.parse('novecentos e quarenta e nove'), '949')

  assert.equal(porExtenso.parse('novecentos e cinquenta'), '950')
  assert.equal(porExtenso.parse('novecentos e cinquenta e um'), '951')
  assert.equal(porExtenso.parse('novecentos e cinquenta e dois'), '952')
  assert.equal(porExtenso.parse('novecentos e cinquenta e três'), '953')
  assert.equal(porExtenso.parse('novecentos e cinquenta e quatro'), '954')
  assert.equal(porExtenso.parse('novecentos e cinquenta e cinco'), '955')
  assert.equal(porExtenso.parse('novecentos e cinquenta e seis'), '956')
  assert.equal(porExtenso.parse('novecentos e cinquenta e sete'), '957')
  assert.equal(porExtenso.parse('novecentos e cinquenta e oito'), '958')
  assert.equal(porExtenso.parse('novecentos e cinquenta e nove'), '959')

  assert.equal(porExtenso.parse('novecentos e sessenta'), '960')
  assert.equal(porExtenso.parse('novecentos e sessenta e um'), '961')
  assert.equal(porExtenso.parse('novecentos e sessenta e dois'), '962')
  assert.equal(porExtenso.parse('novecentos e sessenta e três'), '963')
  assert.equal(porExtenso.parse('novecentos e sessenta e quatro'), '964')
  assert.equal(porExtenso.parse('novecentos e sessenta e cinco'), '965')
  assert.equal(porExtenso.parse('novecentos e sessenta e seis'), '966')
  assert.equal(porExtenso.parse('novecentos e sessenta e sete'), '967')
  assert.equal(porExtenso.parse('novecentos e sessenta e oito'), '968')
  assert.equal(porExtenso.parse('novecentos e sessenta e nove'), '969')

  assert.equal(porExtenso.parse('novecentos e setenta'), '970')
  assert.equal(porExtenso.parse('novecentos e setenta e um'), '971')
  assert.equal(porExtenso.parse('novecentos e setenta e dois'), '972')
  assert.equal(porExtenso.parse('novecentos e setenta e três'), '973')
  assert.equal(porExtenso.parse('novecentos e setenta e quatro'), '974')
  assert.equal(porExtenso.parse('novecentos e setenta e cinco'), '975')
  assert.equal(porExtenso.parse('novecentos e setenta e seis'), '976')
  assert.equal(porExtenso.parse('novecentos e setenta e sete'), '977')
  assert.equal(porExtenso.parse('novecentos e setenta e oito'), '978')
  assert.equal(porExtenso.parse('novecentos e setenta e nove'), '979')

  assert.equal(porExtenso.parse('novecentos e oitenta'), '980')
  assert.equal(porExtenso.parse('novecentos e oitenta e um'), '981')
  assert.equal(porExtenso.parse('novecentos e oitenta e dois'), '982')
  assert.equal(porExtenso.parse('novecentos e oitenta e três'), '983')
  assert.equal(porExtenso.parse('novecentos e oitenta e quatro'), '984')
  assert.equal(porExtenso.parse('novecentos e oitenta e cinco'), '985')
  assert.equal(porExtenso.parse('novecentos e oitenta e seis'), '986')
  assert.equal(porExtenso.parse('novecentos e oitenta e sete'), '987')
  assert.equal(porExtenso.parse('novecentos e oitenta e oito'), '988')
  assert.equal(porExtenso.parse('novecentos e oitenta e nove'), '989')

  assert.equal(porExtenso.parse('novecentos e noventa'), '990')
  assert.equal(porExtenso.parse('novecentos e noventa e um'), '991')
  assert.equal(porExtenso.parse('novecentos e noventa e dois'), '992')
  assert.equal(porExtenso.parse('novecentos e noventa e três'), '993')
  assert.equal(porExtenso.parse('novecentos e noventa e quatro'), '994')
  assert.equal(porExtenso.parse('novecentos e noventa e cinco'), '995')
  assert.equal(porExtenso.parse('novecentos e noventa e seis'), '996')
  assert.equal(porExtenso.parse('novecentos e noventa e sete'), '997')
  assert.equal(porExtenso.parse('novecentos e noventa e oito'), '998')
  assert.equal(porExtenso.parse('novecentos e noventa e nove'), '999')
})
